# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/load_balancer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.apploadbalancer.v1 import logging_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2
from yandex.cloud.apploadbalancer.v1 import target_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/apploadbalancer/v1/load_balancer.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a-yandex/cloud/apploadbalancer/v1/logging.proto\x1a\x32yandex/cloud/apploadbalancer/v1/target_group.proto\"\xa7\x06\n\x0cLoadBalancer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12I\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.apploadbalancer.v1.LoadBalancer.LabelsEntry\x12\x44\n\x06status\x18\x06 \x01(\x0e\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancer.Status\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\x12<\n\tlisteners\x18\t \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.Listener\x12L\n\x11\x61llocation_policy\x18\n \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.AllocationPolicy\x12\x14\n\x0clog_group_id\x18\x0b \x01(\t\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12.\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x11\x61uto_scale_policy\x18\x0e \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.AutoScalePolicy\x12@\n\x0blog_options\x18\x0f \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\"\x9f\x02\n\x07\x41\x64\x64ress\x12U\n\x15\x65xternal_ipv4_address\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressH\x00\x12U\n\x15internal_ipv4_address\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.InternalIpv4AddressH\x00\x12U\n\x15\x65xternal_ipv6_address\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressH\x00\x42\x0f\n\x07\x61\x64\x64ress\x12\x04\xc0\xc1\x31\x01\"&\n\x13\x45xternalIpv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"9\n\x13InternalIpv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"&\n\x13\x45xternalIpv6Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"M\n\x08Location\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12\x17\n\x0f\x64isable_traffic\x18\x03 \x01(\x08\"]\n\x10\x41llocationPolicy\x12I\n\tlocations\x18\x01 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.LocationB\x0b\x82\xc8\x31\x03>=1\x90\xc8\x31\x01\"\xad\x02\n\x08Listener\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\tendpoints\x18\x02 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.Endpoint\x12=\n\x04http\x18\x03 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.HttpListenerH\x00\x12;\n\x03tls\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TlsListenerH\x00\x12\x41\n\x06stream\x18\x05 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.StreamListenerH\x00\x42\x10\n\x08listener\x12\x04\xc0\xc1\x31\x01\"q\n\x08\x45ndpoint\x12\x43\n\taddresses\x18\x01 \x03(\x0b\x32(.yandex.cloud.apploadbalancer.v1.AddressB\x06\x82\xc8\x31\x02>0\x12 \n\x05ports\x18\x02 \x03(\x03\x42\x11\xfa\xc7\x31\x07\x31-65535\x82\xc8\x31\x02>0\"\x8c\x01\n\x0cHttpListener\x12=\n\x07handler\x18\x01 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpHandler\x12=\n\tredirects\x18\x02 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.Redirects\"\x9a\x01\n\x0bTlsListener\x12J\n\x0f\x64\x65\x66\x61ult_handler\x18\x01 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\x12?\n\x0csni_handlers\x18\x02 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.SniMatch\"W\n\x0eStreamListener\x12\x45\n\x07handler\x18\x01 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamHandlerB\x04\xe8\xc7\x31\x01\".\n\x0cHttp2Options\x12\x1e\n\x16max_concurrent_streams\x18\x01 \x01(\x03\"/\n\rStreamHandler\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xb6\x01\n\x0bHttpHandler\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x46\n\rhttp2_options\x18\x02 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.Http2OptionsH\x00\x12\x16\n\x0c\x61llow_http10\x18\x03 \x01(\x08H\x00\x12\x1a\n\x12rewrite_request_id\x18\x04 \x01(\x08\x42\x13\n\x11protocol_settings\"\"\n\tRedirects\x12\x15\n\rhttp_to_https\x18\x01 \x01(\x08\"\x80\x01\n\x08SniMatch\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0cserver_names\x18\x02 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x42\n\x07handler\x18\x03 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\"\xce\x01\n\nTlsHandler\x12\x44\n\x0chttp_handler\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpHandlerH\x00\x12H\n\x0estream_handler\x18\x04 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamHandlerH\x00\x12\x1f\n\x0f\x63\x65rtificate_ids\x18\x03 \x03(\tB\x06\x82\xc8\x31\x02>0B\x0f\n\x07handler\x12\x04\xc0\xc1\x31\x01\"\x8c\x04\n\x0bTargetState\x12N\n\x06status\x18\x01 \x01(\x0b\x32>.yandex.cloud.apploadbalancer.v1.TargetState.HealthcheckStatus\x12=\n\x06target\x18\x02 \x01(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x04\xe8\xc7\x31\x01\x1an\n\x11HealthcheckStatus\x12Y\n\rzone_statuses\x18\x01 \x03(\x0b\x32\x42.yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus\x1a\x8d\x01\n\x15ZoneHealthcheckStatus\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x43\n\x06status\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.apploadbalancer.v1.TargetState.Status\x12\x18\n\x10\x66\x61iled_active_hc\x18\x03 \x01(\x08\"n\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\x15\n\x11PARTIALLY_HEALTHY\x10\x02\x12\r\n\tUNHEALTHY\x10\x03\x12\x0c\n\x08\x44RAINING\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\"R\n\x0f\x41utoScalePolicy\x12!\n\rmin_zone_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1c\n\x08max_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000Bz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _LOADBALANCER_LABELSENTRY._options = None
  _LOADBALANCER_LABELSENTRY._serialized_options = b'8\001'
  _ADDRESS.oneofs_by_name['address']._options = None
  _ADDRESS.oneofs_by_name['address']._serialized_options = b'\300\3011\001'
  _LOCATION.fields_by_name['zone_id']._options = None
  _LOCATION.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _ALLOCATIONPOLICY.fields_by_name['locations']._options = None
  _ALLOCATIONPOLICY.fields_by_name['locations']._serialized_options = b'\202\3101\003>=1\220\3101\001'
  _LISTENER.oneofs_by_name['listener']._options = None
  _LISTENER.oneofs_by_name['listener']._serialized_options = b'\300\3011\001'
  _LISTENER.fields_by_name['name']._options = None
  _LISTENER.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _ENDPOINT.fields_by_name['addresses']._options = None
  _ENDPOINT.fields_by_name['addresses']._serialized_options = b'\202\3101\002>0'
  _ENDPOINT.fields_by_name['ports']._options = None
  _ENDPOINT.fields_by_name['ports']._serialized_options = b'\372\3071\0071-65535\202\3101\002>0'
  _TLSLISTENER.fields_by_name['default_handler']._options = None
  _TLSLISTENER.fields_by_name['default_handler']._serialized_options = b'\350\3071\001'
  _STREAMLISTENER.fields_by_name['handler']._options = None
  _STREAMLISTENER.fields_by_name['handler']._serialized_options = b'\350\3071\001'
  _STREAMHANDLER.fields_by_name['backend_group_id']._options = None
  _STREAMHANDLER.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _SNIMATCH.fields_by_name['name']._options = None
  _SNIMATCH.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _SNIMATCH.fields_by_name['server_names']._options = None
  _SNIMATCH.fields_by_name['server_names']._serialized_options = b'\202\3101\002>0'
  _SNIMATCH.fields_by_name['handler']._options = None
  _SNIMATCH.fields_by_name['handler']._serialized_options = b'\350\3071\001'
  _TLSHANDLER.oneofs_by_name['handler']._options = None
  _TLSHANDLER.oneofs_by_name['handler']._serialized_options = b'\300\3011\001'
  _TLSHANDLER.fields_by_name['certificate_ids']._options = None
  _TLSHANDLER.fields_by_name['certificate_ids']._serialized_options = b'\202\3101\002>0'
  _TARGETSTATE_ZONEHEALTHCHECKSTATUS.fields_by_name['zone_id']._options = None
  _TARGETSTATE_ZONEHEALTHCHECKSTATUS.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _TARGETSTATE.fields_by_name['target']._options = None
  _TARGETSTATE.fields_by_name['target']._serialized_options = b'\350\3071\001'
  _AUTOSCALEPOLICY.fields_by_name['min_zone_size']._options = None
  _AUTOSCALEPOLICY.fields_by_name['min_zone_size']._serialized_options = b'\372\3071\0060-1000'
  _AUTOSCALEPOLICY.fields_by_name['max_size']._options = None
  _AUTOSCALEPOLICY.fields_by_name['max_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LOADBALANCER']._serialized_start=252
  _globals['_LOADBALANCER']._serialized_end=1059
  _globals['_LOADBALANCER_LABELSENTRY']._serialized_start=899
  _globals['_LOADBALANCER_LABELSENTRY']._serialized_end=944
  _globals['_LOADBALANCER_STATUS']._serialized_start=946
  _globals['_LOADBALANCER_STATUS']._serialized_end=1059
  _globals['_ADDRESS']._serialized_start=1062
  _globals['_ADDRESS']._serialized_end=1349
  _globals['_EXTERNALIPV4ADDRESS']._serialized_start=1351
  _globals['_EXTERNALIPV4ADDRESS']._serialized_end=1389
  _globals['_INTERNALIPV4ADDRESS']._serialized_start=1391
  _globals['_INTERNALIPV4ADDRESS']._serialized_end=1448
  _globals['_EXTERNALIPV6ADDRESS']._serialized_start=1450
  _globals['_EXTERNALIPV6ADDRESS']._serialized_end=1488
  _globals['_LOCATION']._serialized_start=1490
  _globals['_LOCATION']._serialized_end=1567
  _globals['_ALLOCATIONPOLICY']._serialized_start=1569
  _globals['_ALLOCATIONPOLICY']._serialized_end=1662
  _globals['_LISTENER']._serialized_start=1665
  _globals['_LISTENER']._serialized_end=1966
  _globals['_ENDPOINT']._serialized_start=1968
  _globals['_ENDPOINT']._serialized_end=2081
  _globals['_HTTPLISTENER']._serialized_start=2084
  _globals['_HTTPLISTENER']._serialized_end=2224
  _globals['_TLSLISTENER']._serialized_start=2227
  _globals['_TLSLISTENER']._serialized_end=2381
  _globals['_STREAMLISTENER']._serialized_start=2383
  _globals['_STREAMLISTENER']._serialized_end=2470
  _globals['_HTTP2OPTIONS']._serialized_start=2472
  _globals['_HTTP2OPTIONS']._serialized_end=2518
  _globals['_STREAMHANDLER']._serialized_start=2520
  _globals['_STREAMHANDLER']._serialized_end=2567
  _globals['_HTTPHANDLER']._serialized_start=2570
  _globals['_HTTPHANDLER']._serialized_end=2752
  _globals['_REDIRECTS']._serialized_start=2754
  _globals['_REDIRECTS']._serialized_end=2788
  _globals['_SNIMATCH']._serialized_start=2791
  _globals['_SNIMATCH']._serialized_end=2919
  _globals['_TLSHANDLER']._serialized_start=2922
  _globals['_TLSHANDLER']._serialized_end=3128
  _globals['_TARGETSTATE']._serialized_start=3131
  _globals['_TARGETSTATE']._serialized_end=3655
  _globals['_TARGETSTATE_HEALTHCHECKSTATUS']._serialized_start=3289
  _globals['_TARGETSTATE_HEALTHCHECKSTATUS']._serialized_end=3399
  _globals['_TARGETSTATE_ZONEHEALTHCHECKSTATUS']._serialized_start=3402
  _globals['_TARGETSTATE_ZONEHEALTHCHECKSTATUS']._serialized_end=3543
  _globals['_TARGETSTATE_STATUS']._serialized_start=3545
  _globals['_TARGETSTATE_STATUS']._serialized_end=3655
  _globals['_AUTOSCALEPOLICY']._serialized_start=3657
  _globals['_AUTOSCALEPOLICY']._serialized_end=3739
# @@protoc_insertion_point(module_scope)
