# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/eventrouter/v1/connector_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.eventrouter.v1 import connector_pb2 as yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_connector__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/serverless/eventrouter/v1/connector_service.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x36yandex/cloud/serverless/eventrouter/v1/connector.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x13GetConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8b\x01\n\x15ListConnectorsRequest\x12\x10\n\x06\x62us_id\x18\x01 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x02 \x01(\tH\x00\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\tB\x14\n\x0c\x63ontainer_id\x12\x04\xc0\xc1\x31\x01\"x\n\x16ListConnectorsResponse\x12\x45\n\nconnectors\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.serverless.eventrouter.v1.Connector\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa5\x03\n\x16\x43reateConnectorRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.serverless.eventrouter.v1.CreateConnectorRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x06source\x18\x05 \x01(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.Source\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x17\x43reateConnectorMetadata\x12\x14\n\x0c\x63onnector_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\"\x9c\x03\n\x16UpdateConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x05 \x03(\x0b\x32J.yandex.cloud.serverless.eventrouter.v1.UpdateConnectorRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x17UpdateConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x16\x44\x65leteConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"5\n\x17\x44\x65leteConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x96\x01\n\x1eListConnectorOperationsRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"q\n\x1fListConnectorOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x15StartConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x16StartConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x14StopConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"3\n\x15StopConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xf8\x11\n\x10\x43onnectorService\x12\xa8\x01\n\x03Get\x12;.yandex.cloud.serverless.eventrouter.v1.GetConnectorRequest\x1a\x31.yandex.cloud.serverless.eventrouter.v1.Connector\"1\x82\xd3\xe4\x93\x02+\x12)/eventrouter/v1/connectors/{connector_id}\x12\xa9\x01\n\x04List\x12=.yandex.cloud.serverless.eventrouter.v1.ListConnectorsRequest\x1a>.yandex.cloud.serverless.eventrouter.v1.ListConnectorsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/eventrouter/v1/connectors\x12\xba\x01\n\x06\x43reate\x12>.yandex.cloud.serverless.eventrouter.v1.CreateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2*$\n\x17\x43reateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02\x1f\"\x1a/eventrouter/v1/connectors:\x01*\x12\xc9\x01\n\x06Update\x12>.yandex.cloud.serverless.eventrouter.v1.UpdateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*$\n\x17UpdateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02.2)/eventrouter/v1/connectors/{connector_id}:\x01*\x12\xd2\x01\n\x06\x44\x65lete\x12>.yandex.cloud.serverless.eventrouter.v1.DeleteConnectorRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*0\n\x17\x44\x65leteConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+*)/eventrouter/v1/connectors/{connector_id}\x12\xd5\x01\n\x05Start\x12=.yandex.cloud.serverless.eventrouter.v1.StartConnectorRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*/\n\x16StartConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31\"//eventrouter/v1/connectors/{connector_id}:start\x12\xd1\x01\n\x04Stop\x12<.yandex.cloud.serverless.eventrouter.v1.StopConnectorRequest\x1a!.yandex.cloud.operation.Operation\"h\xb2\xd2*.\n\x15StopConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x30\"./eventrouter/v1/connectors/{connector_id}:stop\x12\xba\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/eventrouter/v1/connectors/{resource_id}:listAccessBindings\x12\xea\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/eventrouter/v1/connectors/{resource_id}:setAccessBindings:\x01*\x12\xf6\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\x32=/eventrouter/v1/connectors/{resource_id}:updateAccessBindings:\x01*\x12\xdf\x01\n\x0eListOperations\x12\x46.yandex.cloud.serverless.eventrouter.v1.ListConnectorOperationsRequest\x1aG.yandex.cloud.serverless.eventrouter.v1.ListConnectorOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/eventrouter/v1/connectors/{connector_id}/operationsB\x8b\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x05PERCSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.connector_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\005PERCSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _GETCONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _GETCONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _LISTCONNECTORSREQUEST.oneofs_by_name['container_id']._options = None
  _LISTCONNECTORSREQUEST.oneofs_by_name['container_id']._serialized_options = b'\300\3011\001'
  _CREATECONNECTORREQUEST_LABELSENTRY._options = None
  _CREATECONNECTORREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECONNECTORREQUEST.fields_by_name['bus_id']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _CREATECONNECTORREQUEST.fields_by_name['name']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATECONNECTORREQUEST.fields_by_name['description']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECONNECTORREQUEST.fields_by_name['labels']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECONNECTORREQUEST_LABELSENTRY._options = None
  _UPDATECONNECTORREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _UPDATECONNECTORREQUEST.fields_by_name['name']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATECONNECTORREQUEST.fields_by_name['description']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECONNECTORREQUEST.fields_by_name['labels']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _UPDATECONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _DELETECONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _DELETECONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _DELETECONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _DELETECONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['connector_id']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _STARTCONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _STARTCONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _STARTCONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _STARTCONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _STOPCONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _STOPCONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _STOPCONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _STOPCONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _CONNECTORSERVICE.methods_by_name['Get']._options = None
  _CONNECTORSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/eventrouter/v1/connectors/{connector_id}'
  _CONNECTORSERVICE.methods_by_name['List']._options = None
  _CONNECTORSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/eventrouter/v1/connectors'
  _CONNECTORSERVICE.methods_by_name['Create']._options = None
  _CONNECTORSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateConnectorMetadata\022\tConnector\202\323\344\223\002\037\"\032/eventrouter/v1/connectors:\001*'
  _CONNECTORSERVICE.methods_by_name['Update']._options = None
  _CONNECTORSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateConnectorMetadata\022\tConnector\202\323\344\223\002.2)/eventrouter/v1/connectors/{connector_id}:\001*'
  _CONNECTORSERVICE.methods_by_name['Delete']._options = None
  _CONNECTORSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\002+*)/eventrouter/v1/connectors/{connector_id}'
  _CONNECTORSERVICE.methods_by_name['Start']._options = None
  _CONNECTORSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*/\n\026StartConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\0021\"//eventrouter/v1/connectors/{connector_id}:start'
  _CONNECTORSERVICE.methods_by_name['Stop']._options = None
  _CONNECTORSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*.\n\025StopConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\0020\"./eventrouter/v1/connectors/{connector_id}:stop'
  _CONNECTORSERVICE.methods_by_name['ListAccessBindings']._options = None
  _CONNECTORSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002=\022;/eventrouter/v1/connectors/{resource_id}:listAccessBindings'
  _CONNECTORSERVICE.methods_by_name['SetAccessBindings']._options = None
  _CONNECTORSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/eventrouter/v1/connectors/{resource_id}:setAccessBindings:\001*'
  _CONNECTORSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _CONNECTORSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B2=/eventrouter/v1/connectors/{resource_id}:updateAccessBindings:\001*'
  _CONNECTORSERVICE.methods_by_name['ListOperations']._options = None
  _CONNECTORSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0026\0224/eventrouter/v1/connectors/{connector_id}/operations'
  _globals['_GETCONNECTORREQUEST']._serialized_start=365
  _globals['_GETCONNECTORREQUEST']._serialized_end=414
  _globals['_LISTCONNECTORSREQUEST']._serialized_start=417
  _globals['_LISTCONNECTORSREQUEST']._serialized_end=556
  _globals['_LISTCONNECTORSRESPONSE']._serialized_start=558
  _globals['_LISTCONNECTORSRESPONSE']._serialized_end=678
  _globals['_CREATECONNECTORREQUEST']._serialized_start=681
  _globals['_CREATECONNECTORREQUEST']._serialized_end=1102
  _globals['_CREATECONNECTORREQUEST_LABELSENTRY']._serialized_start=1057
  _globals['_CREATECONNECTORREQUEST_LABELSENTRY']._serialized_end=1102
  _globals['_CREATECONNECTORMETADATA']._serialized_start=1104
  _globals['_CREATECONNECTORMETADATA']._serialized_end=1167
  _globals['_UPDATECONNECTORREQUEST']._serialized_start=1170
  _globals['_UPDATECONNECTORREQUEST']._serialized_end=1582
  _globals['_UPDATECONNECTORREQUEST_LABELSENTRY']._serialized_start=1057
  _globals['_UPDATECONNECTORREQUEST_LABELSENTRY']._serialized_end=1102
  _globals['_UPDATECONNECTORMETADATA']._serialized_start=1584
  _globals['_UPDATECONNECTORMETADATA']._serialized_end=1637
  _globals['_DELETECONNECTORREQUEST']._serialized_start=1639
  _globals['_DELETECONNECTORREQUEST']._serialized_end=1691
  _globals['_DELETECONNECTORMETADATA']._serialized_start=1693
  _globals['_DELETECONNECTORMETADATA']._serialized_end=1746
  _globals['_LISTCONNECTOROPERATIONSREQUEST']._serialized_start=1749
  _globals['_LISTCONNECTOROPERATIONSREQUEST']._serialized_end=1899
  _globals['_LISTCONNECTOROPERATIONSRESPONSE']._serialized_start=1901
  _globals['_LISTCONNECTOROPERATIONSRESPONSE']._serialized_end=2014
  _globals['_STARTCONNECTORREQUEST']._serialized_start=2016
  _globals['_STARTCONNECTORREQUEST']._serialized_end=2067
  _globals['_STARTCONNECTORMETADATA']._serialized_start=2069
  _globals['_STARTCONNECTORMETADATA']._serialized_end=2121
  _globals['_STOPCONNECTORREQUEST']._serialized_start=2123
  _globals['_STOPCONNECTORREQUEST']._serialized_end=2173
  _globals['_STOPCONNECTORMETADATA']._serialized_start=2175
  _globals['_STOPCONNECTORMETADATA']._serialized_end=2226
  _globals['_CONNECTORSERVICE']._serialized_start=2229
  _globals['_CONNECTORSERVICE']._serialized_end=4525
# @@protoc_insertion_point(module_scope)
