# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/common/tag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/loadtesting/api/v1/common/tag.proto\x12&yandex.cloud.loadtesting.api.v1.common\"!\n\x03Tag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tB\x7f\n*yandex.cloud.api.loadtesting.api.v1.commonZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/common;commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.common.tag_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.commonZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/common;common'
  _globals['_TAG']._serialized_start=92
  _globals['_TAG']._serialized_end=125
# @@protoc_insertion_point(module_scope)
