"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.organizationmanager.v1.user_ssh_key_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___GetUserSshKeyRequest = GetUserSshKeyRequest

@typing.final
class ListUserSshKeysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    subject_id: builtins.str
    """if empty, list all organization keys"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token", "subject_id", b"subject_id"]) -> None: ...

global___ListUserSshKeysRequest = ListUserSshKeysRequest

@typing.final
class ListUserSshKeysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SSH_KEYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def ssh_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.user_ssh_key_pb2.UserSshKey]: ...
    def __init__(
        self,
        *,
        ssh_keys: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.user_ssh_key_pb2.UserSshKey] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "ssh_keys", b"ssh_keys"]) -> None: ...

global___ListUserSshKeysResponse = ListUserSshKeysResponse

@typing.final
class CreateUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    subject_id: builtins.str
    name: builtins.str
    data: builtins.str
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        name: builtins.str = ...,
        data: builtins.str = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "expires_at", b"expires_at", "name", b"name", "organization_id", b"organization_id", "subject_id", b"subject_id"]) -> None: ...

global___CreateUserSshKeyRequest = CreateUserSshKeyRequest

@typing.final
class CreateUserSshKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    organization_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
        organization_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___CreateUserSshKeyMetadata = CreateUserSshKeyMetadata

@typing.final
class UpdateUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    name: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
        name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["expires_at", b"expires_at", "name", b"name", "update_mask", b"update_mask", "user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___UpdateUserSshKeyRequest = UpdateUserSshKeyRequest

@typing.final
class UpdateUserSshKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___UpdateUserSshKeyMetadata = UpdateUserSshKeyMetadata

@typing.final
class DeleteUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___DeleteUserSshKeyRequest = DeleteUserSshKeyRequest

@typing.final
class DeleteUserSshKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___DeleteUserSshKeyMetadata = DeleteUserSshKeyMetadata
