# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/searchindex/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/ai/assistants/v1/searchindex/common.proto\x12)yandex.cloud.ai.assistants.v1.searchindex\"U\n\x16StaticChunkingStrategy\x12\x1d\n\x15max_chunk_size_tokens\x18\x01 \x01(\x03\x12\x1c\n\x14\x63hunk_overlap_tokens\x18\x02 \x01(\x03\"|\n\x10\x43hunkingStrategy\x12\\\n\x0fstatic_strategy\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.ai.assistants.v1.searchindex.StaticChunkingStrategyH\x00\x42\n\n\x08StrategyB\x8a\x01\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.searchindex.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindex'
  _globals['_STATICCHUNKINGSTRATEGY']._serialized_start=101
  _globals['_STATICCHUNKINGSTRATEGY']._serialized_end=186
  _globals['_CHUNKINGSTRATEGY']._serialized_start=188
  _globals['_CHUNKINGSTRATEGY']._serialized_end=312
# @@protoc_insertion_point(module_scope)
