# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.sqlserver.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/sqlserver/v1/database_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a,yandex/cloud/mdb/sqlserver/v1/database.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"m\n\x12GetDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"v\n\x14ListDatabasesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x15ListDatabasesResponse\x12:\n\tdatabases\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x83\x01\n\x15\x43reateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12H\n\rdatabase_spec\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.sqlserver.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\"C\n\x16\x43reateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"p\n\x15\x44\x65leteDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"C\n\x16\x44\x65leteDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\xc3\x01\n\x16RestoreDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rfrom_database\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01J\x04\x08\x05\x10\x06\"\x86\x01\n\x17RestoreDatabaseMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rfrom_database\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"\x9b\x01\n\x1bImportDatabaseBackupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\x12\x13\n\x05\x66iles\x18\x05 \x03(\tB\x04\xe8\xc7\x31\x01\"\x7f\n\x1cImportDatabaseBackupMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\"\x96\x01\n\x1b\x45xportDatabaseBackupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\"\x7f\n\x1c\x45xportDatabaseBackupMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t2\xbe\x0b\n\x0f\x44\x61tabaseService\x12\xac\x01\n\x03Get\x12\x31.yandex.cloud.mdb.sqlserver.v1.GetDatabaseRequest\x1a\'.yandex.cloud.mdb.sqlserver.v1.Database\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}\x12\xac\x01\n\x04List\x12\x33.yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest\x1a\x34.yandex.cloud.mdb.sqlserver.v1.ListDatabasesResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/mdb/sqlserver/v1/clusters/{cluster_id}/databases\x12\xc5\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.sqlserver.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x36\"1/mdb/sqlserver/v1/clusters/{cluster_id}/databases:\x01*\x12\xd0\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*#\n\x17RestoreDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/databases:restore:\x01*\x12\xde\x01\n\x0cImportBackup\x12:.yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*(\n\x1cImportDatabaseBackupMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02=\"8/mdb/sqlserver/v1/clusters/{cluster_id}/databases:import:\x01*\x12\xee\x01\n\x0c\x45xportBackup\x12:.yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*(\n\x1c\x45xportDatabaseBackupMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02M\"H/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}:export:\x01*\x12\xdf\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43*A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}Bv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSDSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSDSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _GETDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _GETDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETDATABASEREQUEST.fields_by_name['database_name']._options = None
  _GETDATABASEREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _LISTDATABASESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTDATABASESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEDATABASEREQUEST.fields_by_name['database_spec']._options = None
  _CREATEDATABASEREQUEST.fields_by_name['database_spec']._serialized_options = b'\350\3071\001'
  _DELETEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEDATABASEREQUEST.fields_by_name['database_name']._options = None
  _DELETEDATABASEREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _RESTOREDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTOREDATABASEREQUEST.fields_by_name['database_name']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEREQUEST.fields_by_name['from_database']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['from_database']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEREQUEST.fields_by_name['backup_id']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEREQUEST.fields_by_name['time']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['time']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['cluster_id']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['database_name']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['from_database']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['from_database']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['backup_id']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['files']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['files']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._options = None
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._options = None
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._options = None
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._options = None
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._options = None
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._options = None
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._options = None
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._options = None
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _DATABASESERVICE.methods_by_name['Get']._options = None
  _DATABASESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002C\022A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}'
  _DATABASESERVICE.methods_by_name['List']._options = None
  _DATABASESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0023\0221/mdb/sqlserver/v1/clusters/{cluster_id}/databases'
  _DATABASESERVICE.methods_by_name['Create']._options = None
  _DATABASESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateDatabaseMetadata\022\010Database\202\323\344\223\0026\"1/mdb/sqlserver/v1/clusters/{cluster_id}/databases:\001*'
  _DATABASESERVICE.methods_by_name['Restore']._options = None
  _DATABASESERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*#\n\027RestoreDatabaseMetadata\022\010Database\202\323\344\223\002>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/databases:restore:\001*'
  _DATABASESERVICE.methods_by_name['ImportBackup']._options = None
  _DATABASESERVICE.methods_by_name['ImportBackup']._serialized_options = b'\262\322*(\n\034ImportDatabaseBackupMetadata\022\010Database\202\323\344\223\002=\"8/mdb/sqlserver/v1/clusters/{cluster_id}/databases:import:\001*'
  _DATABASESERVICE.methods_by_name['ExportBackup']._options = None
  _DATABASESERVICE.methods_by_name['ExportBackup']._serialized_options = b'\262\322*(\n\034ExportDatabaseBackupMetadata\022\010Database\202\323\344\223\002M\"H/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}:export:\001*'
  _DATABASESERVICE.methods_by_name['Delete']._options = None
  _DATABASESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty\202\323\344\223\002C*A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}'
  _globals['_GETDATABASEREQUEST']._serialized_start=301
  _globals['_GETDATABASEREQUEST']._serialized_end=410
  _globals['_LISTDATABASESREQUEST']._serialized_start=412
  _globals['_LISTDATABASESREQUEST']._serialized_end=530
  _globals['_LISTDATABASESRESPONSE']._serialized_start=532
  _globals['_LISTDATABASESRESPONSE']._serialized_end=640
  _globals['_CREATEDATABASEREQUEST']._serialized_start=643
  _globals['_CREATEDATABASEREQUEST']._serialized_end=774
  _globals['_CREATEDATABASEMETADATA']._serialized_start=776
  _globals['_CREATEDATABASEMETADATA']._serialized_end=843
  _globals['_DELETEDATABASEREQUEST']._serialized_start=845
  _globals['_DELETEDATABASEREQUEST']._serialized_end=957
  _globals['_DELETEDATABASEMETADATA']._serialized_start=959
  _globals['_DELETEDATABASEMETADATA']._serialized_end=1026
  _globals['_RESTOREDATABASEREQUEST']._serialized_start=1029
  _globals['_RESTOREDATABASEREQUEST']._serialized_end=1224
  _globals['_RESTOREDATABASEMETADATA']._serialized_start=1227
  _globals['_RESTOREDATABASEMETADATA']._serialized_end=1361
  _globals['_IMPORTDATABASEBACKUPREQUEST']._serialized_start=1364
  _globals['_IMPORTDATABASEBACKUPREQUEST']._serialized_end=1519
  _globals['_IMPORTDATABASEBACKUPMETADATA']._serialized_start=1521
  _globals['_IMPORTDATABASEBACKUPMETADATA']._serialized_end=1648
  _globals['_EXPORTDATABASEBACKUPREQUEST']._serialized_start=1651
  _globals['_EXPORTDATABASEBACKUPREQUEST']._serialized_end=1801
  _globals['_EXPORTDATABASEBACKUPMETADATA']._serialized_start=1803
  _globals['_EXPORTDATABASEBACKUPMETADATA']._serialized_end=1930
  _globals['_DATABASESERVICE']._serialized_start=1933
  _globals['_DATABASESERVICE']._serialized_end=3403
# @@protoc_insertion_point(module_scope)
