# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/config/clickhouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/clickhouse/v1/config/clickhouse.proto\x12%yandex.cloud.mdb.clickhouse.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xd1k\n\x10\x43lickhouseConfig\x12S\n\tlog_level\x18\x01 \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.LogLevel\x12U\n\nmerge_tree\x18\x02 \x01(\x0b\x32\x41.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.MergeTree\x12X\n\x0b\x63ompression\x18\x03 \x03(\x0b\x32\x43.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Compression\x12`\n\x0c\x64ictionaries\x18\x04 \x03(\x0b\x32J.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary\x12_\n\x0fgraphite_rollup\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.GraphiteRollup\x12L\n\x05kafka\x18# \x01(\x0b\x32=.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka\x12X\n\x0ckafka_topics\x18$ \x03(\x0b\x32\x42.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.KafkaTopic\x12R\n\x08rabbitmq\x18% \x01(\x0b\x32@.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Rabbitmq\x12>\n\x0fmax_connections\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=10\x12\x45\n\x16max_concurrent_queries\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=10\x12\x37\n\x12keep_alive_timeout\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17uncompressed_cache_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x0fmark_cache_size\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12;\n\x16max_table_size_to_drop\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1amax_partition_size_to_drop\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12M\n$builtin_dictionaries_reload_interval\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\x12\x10\n\x08timezone\x18\x0e \x01(\t\x12\x33\n\x0fgeobase_enabled\x18\x42 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0bgeobase_uri\x18\x0f \x01(\t\x12=\n\x18query_log_retention_size\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18query_log_retention_time\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x18query_thread_log_enabled\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x44\n\x1fquery_thread_log_retention_size\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x1fquery_thread_log_retention_time\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17part_log_retention_size\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17part_log_retention_time\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x12metric_log_enabled\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x19metric_log_retention_size\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19metric_log_retention_time\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x11trace_log_enabled\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x18trace_log_retention_size\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18trace_log_retention_time\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x10text_log_enabled\x18\x1d \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x17text_log_retention_size\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17text_log_retention_time\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12X\n\x0etext_log_level\x18  \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.LogLevel\x12\x42\n\x1eopentelemetry_span_log_enabled\x18* \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12S\n%opentelemetry_span_log_retention_size\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12S\n%opentelemetry_span_log_retention_time\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12;\n\x17query_views_log_enabled\x18\x31 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n\x1equery_views_log_retention_size\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n\x1equery_views_log_retention_time\x18\x33 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x1f\x61synchronous_metric_log_enabled\x18\x34 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n&asynchronous_metric_log_retention_size\x18\x35 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n&asynchronous_metric_log_retention_time\x18\x36 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x37\n\x13session_log_enabled\x18\x39 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12H\n\x1asession_log_retention_size\x18: \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12H\n\x1asession_log_retention_time\x18; \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x15zookeeper_log_enabled\x18< \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x1czookeeper_log_retention_size\x18= \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12J\n\x1czookeeper_log_retention_time\x18> \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x1f\x61synchronous_insert_log_enabled\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n&asynchronous_insert_log_retention_size\x18@ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n&asynchronous_insert_log_retention_time\x18\x41 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x41\n\x14\x62\x61\x63kground_pool_size\x18! \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12Z\n-background_merges_mutations_concurrency_ratio\x18\x30 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12J\n\x1d\x62\x61\x63kground_schedule_pool_size\x18\" \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12I\n\x1c\x62\x61\x63kground_fetches_pool_size\x18& \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x46\n\x19\x62\x61\x63kground_move_pool_size\x18\' \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12V\n)background_distributed_schedule_pool_size\x18( \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12W\n*background_buffer_flush_schedule_pool_size\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12Y\n,background_message_broker_schedule_pool_size\x18. \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12H\n\x1b\x62\x61\x63kground_common_pool_size\x18/ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x36\n\x10\x64\x65\x66\x61ult_database\x18+ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x1atotal_memory_profiler_step\x18, \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12M\n\'total_memory_tracker_sample_probability\x18- \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12m\n\x13query_masking_rules\x18\x43 \x03(\x0b\x32H.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.QueryMaskingRuleB\x06\x82\xc8\x31\x02>0\x12:\n\x16\x64ictionaries_lazy_load\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12W\n\x0bquery_cache\x18\x45 \x01(\x0b\x32\x42.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.QueryCache\x1a\xd4\x0f\n\tMergeTree\x12\x44\n\x1freplicated_deduplication_window\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\'replicated_deduplication_window_seconds\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15parts_to_delay_insert\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15parts_to_throw_insert\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1einactive_parts_to_delay_insert\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1einactive_parts_to_throw_insert\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_replicated_merges_in_queue\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12^\n9number_of_free_entries_in_pool_to_lower_max_size_of_merge\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\'max_bytes_to_merge_at_min_space_in_pool\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\'max_bytes_to_merge_at_max_space_in_pool\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17min_bytes_for_wide_part\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16min_rows_for_wide_part\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x13ttl_only_drop_parts\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n%allow_remote_fs_zero_copy_replication\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x16merge_with_ttl_timeout\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12I\n$merge_with_recompression_ttl_timeout\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_parts_in_total\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12J\n%max_number_of_merges_with_ttl_in_pool\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x63leanup_delay_period\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12W\n2number_of_free_entries_in_pool_to_execute_mutation\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12R\n$max_avg_part_size_for_too_many_parts\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n\x1emin_age_to_force_merge_seconds\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n(min_age_to_force_merge_on_partition_only\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n\x18merge_selecting_sleep_ms\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x41\n\x14merge_max_block_size\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x42\n\x1e\x63heck_sample_column_is_correct\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x1cmax_merge_selecting_sleep_ms\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x46\n\x18max_cleanup_delay_period\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x1a\xa0\r\n\x05Kafka\x12i\n\x11security_protocol\x18\x01 \x01(\x0e\x32N.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.SecurityProtocol\x12\x63\n\x0esasl_mechanism\x18\x02 \x01(\x0e\x32K.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.SaslMechanism\x12\x15\n\rsasl_username\x18\x03 \x01(\t\x12\x15\n\rsasl_password\x18\x04 \x01(\t\x12G\n#enable_ssl_certificate_verification\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x14max_poll_interval_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12@\n\x12session_timeout_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12R\n\x05\x64\x65\x62ug\x18\x08 \x01(\x0e\x32\x43.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.Debug\x12h\n\x11\x61uto_offset_reset\x18\t \x01(\x0e\x32M.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.AutoOffsetReset\"\xb7\x01\n\x10SecurityProtocol\x12!\n\x1dSECURITY_PROTOCOL_UNSPECIFIED\x10\x00\x12\x1f\n\x1bSECURITY_PROTOCOL_PLAINTEXT\x10\x01\x12\x19\n\x15SECURITY_PROTOCOL_SSL\x10\x02\x12$\n SECURITY_PROTOCOL_SASL_PLAINTEXT\x10\x03\x12\x1e\n\x1aSECURITY_PROTOCOL_SASL_SSL\x10\x04\"\xa8\x01\n\rSaslMechanism\x12\x1e\n\x1aSASL_MECHANISM_UNSPECIFIED\x10\x00\x12\x19\n\x15SASL_MECHANISM_GSSAPI\x10\x01\x12\x18\n\x14SASL_MECHANISM_PLAIN\x10\x02\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_256\x10\x03\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_512\x10\x04\"\x99\x03\n\x05\x44\x65\x62ug\x12\x15\n\x11\x44\x45\x42UG_UNSPECIFIED\x10\x00\x12\x11\n\rDEBUG_GENERIC\x10\x01\x12\x10\n\x0c\x44\x45\x42UG_BROKER\x10\x02\x12\x0f\n\x0b\x44\x45\x42UG_TOPIC\x10\x03\x12\x12\n\x0e\x44\x45\x42UG_METADATA\x10\x04\x12\x11\n\rDEBUG_FEATURE\x10\x05\x12\x0f\n\x0b\x44\x45\x42UG_QUEUE\x10\x06\x12\r\n\tDEBUG_MSG\x10\x07\x12\x12\n\x0e\x44\x45\x42UG_PROTOCOL\x10\x08\x12\x0e\n\nDEBUG_CGRP\x10\t\x12\x12\n\x0e\x44\x45\x42UG_SECURITY\x10\n\x12\x0f\n\x0b\x44\x45\x42UG_FETCH\x10\x0b\x12\x15\n\x11\x44\x45\x42UG_INTERCEPTOR\x10\x0c\x12\x10\n\x0c\x44\x45\x42UG_PLUGIN\x10\r\x12\x12\n\x0e\x44\x45\x42UG_CONSUMER\x10\x0e\x12\x0f\n\x0b\x44\x45\x42UG_ADMIN\x10\x0f\x12\r\n\tDEBUG_EOS\x10\x10\x12\x0e\n\nDEBUG_MOCK\x10\x11\x12\x12\n\x0e\x44\x45\x42UG_ASSIGNOR\x10\x12\x12\x0e\n\nDEBUG_CONF\x10\x13\x12\x13\n\x0f\x44\x45\x42UG_TELEMETRY\x10\x14\x12\r\n\tDEBUG_ALL\x10\x15\"\x8a\x02\n\x0f\x41utoOffsetReset\x12!\n\x1d\x41UTO_OFFSET_RESET_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x41UTO_OFFSET_RESET_SMALLEST\x10\x01\x12\x1e\n\x1a\x41UTO_OFFSET_RESET_EARLIEST\x10\x02\x12\x1f\n\x1b\x41UTO_OFFSET_RESET_BEGINNING\x10\x03\x12\x1d\n\x19\x41UTO_OFFSET_RESET_LARGEST\x10\x04\x12\x1c\n\x18\x41UTO_OFFSET_RESET_LATEST\x10\x05\x12\x19\n\x15\x41UTO_OFFSET_RESET_END\x10\x06\x12\x1b\n\x17\x41UTO_OFFSET_RESET_ERROR\x10\x07\x1aw\n\nKafkaTopic\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12U\n\x08settings\x18\x02 \x01(\x0b\x32=.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.KafkaB\x04\xe8\xc7\x31\x01\x1a=\n\x08Rabbitmq\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05vhost\x18\x03 \x01(\t\x1a\x90\x02\n\x0b\x43ompression\x12Z\n\x06method\x18\x01 \x01(\x0e\x32J.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Compression.Method\x12\x1e\n\rmin_part_size\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x1b\n\x13min_part_size_ratio\x18\x03 \x01(\x01\x12\x33\n\x05level\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"3\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x07\n\x03LZ4\x10\x01\x12\x08\n\x04ZSTD\x10\x02\x1a\xfc\x1c\n\x12\x45xternalDictionary\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12m\n\tstructure\x18\x02 \x01(\x0b\x32T.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.StructureB\x04\xe8\xc7\x31\x01\x12g\n\x06layout\x18\x03 \x01(\x0b\x32Q.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.LayoutB\x04\xe8\xc7\x31\x01\x12\x18\n\x0e\x66ixed_lifetime\x18\x04 \x01(\x03H\x00\x12j\n\x0elifetime_range\x18\x05 \x01(\x0b\x32P.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.RangeH\x00\x12l\n\x0bhttp_source\x18\x06 \x01(\x0b\x32U.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.HttpSourceH\x01\x12n\n\x0cmysql_source\x18\x07 \x01(\x0b\x32V.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.MysqlSourceH\x01\x12x\n\x11\x63lickhouse_source\x18\x08 \x01(\x0b\x32[.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.ClickhouseSourceH\x01\x12r\n\x0emongodb_source\x18\t \x01(\x0b\x32X.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.MongodbSourceH\x01\x12x\n\x11postgresql_source\x18\n \x01(\x0b\x32[.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.PostgresqlSourceH\x01\x1a\xd7\x01\n\nHttpSource\x12\x11\n\x03url\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x14\n\x06\x66ormat\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12m\n\x07headers\x18\x03 \x03(\x0b\x32\\.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.HttpSource.Header\x1a\x31\n\x06Header\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x1a\xff\x03\n\x0bMysqlSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05table\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x04port\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x0c\n\x04user\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12x\n\x08replicas\x18\x06 \x03(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.MysqlSource.ReplicaB\x06\x82\xc8\x31\x02>0\x12\r\n\x05where\x18\x07 \x01(\t\x12\x18\n\x10invalidate_query\x18\x08 \x01(\t\x12\x34\n\x10\x63lose_connection\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10share_connection\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x7f\n\x07Replica\x12\x1b\n\x04host\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=253\x12\x1c\n\x08priority\x18\x02 \x01(\x03\x42\n\xe8\xc7\x31\x01\xfa\xc7\x31\x02>0\x12\x19\n\x04port\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x0c\n\x04user\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x1a\xce\x01\n\x10\x43lickhouseSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05table\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\x04host\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=253\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x12\n\x04user\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08password\x18\x06 \x01(\t\x12\r\n\x05where\x18\x07 \x01(\t\x12*\n\x06secure\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xa6\x01\n\rMongodbSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\ncollection\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\x04host\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=253\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x12\n\x04user\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x0f\n\x07options\x18\x07 \x01(\t\x1a\x8b\x03\n\x10PostgresqlSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05table\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x05hosts\x18\x03 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x12\n\x04user\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x18\n\x10invalidate_query\x18\x07 \x01(\t\x12u\n\x08ssl_mode\x18\x08 \x01(\x0e\x32\x63.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.PostgresqlSource.SslMode\"g\n\x07SslMode\x12\x18\n\x14SSL_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44ISABLE\x10\x01\x12\t\n\x05\x41LLOW\x10\x02\x12\n\n\x06PREFER\x10\x03\x12\r\n\tVERIFY_CA\x10\x04\x12\x0f\n\x0bVERIFY_FULL\x10\x05\x1a\xde\x06\n\tStructure\x12\x63\n\x02id\x18\x01 \x01(\x0b\x32W.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Id\x12\x65\n\x03key\x18\x03 \x01(\x0b\x32X.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Key\x12q\n\trange_min\x18\x04 \x01(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Attribute\x12q\n\trange_max\x18\x05 \x01(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Attribute\x12z\n\nattributes\x18\x02 \x03(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.AttributeB\x06\x82\xc8\x31\x02>0\x1a\x84\x01\n\tAttribute\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04type\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\nnull_value\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x14\n\x0chierarchical\x18\x05 \x01(\x08\x12\x11\n\tinjective\x18\x06 \x01(\x08\x1a\x18\n\x02Id\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x1a\x81\x01\n\x03Key\x12z\n\nattributes\x18\x01 \x03(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.AttributeB\x06\x82\xc8\x31\x02>0\x1a\xa3\x02\n\x06Layout\x12j\n\x04type\x18\x01 \x01(\x0e\x32V.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Layout.TypeB\x04\xe8\xc7\x31\x01\x12\x15\n\rsize_in_cells\x18\x02 \x01(\x03\x12\x16\n\x0emax_array_size\x18\x03 \x01(\x03\"~\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46LAT\x10\x01\x12\n\n\x06HASHED\x10\x02\x12\x16\n\x12\x43OMPLEX_KEY_HASHED\x10\x03\x12\x10\n\x0cRANGE_HASHED\x10\x04\x12\t\n\x05\x43\x41\x43HE\x10\x05\x12\x15\n\x11\x43OMPLEX_KEY_CACHE\x10\x06\x1a!\n\x05Range\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x42\x10\n\x08lifetime\x12\x04\xc0\xc1\x31\x01\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01\x1a\xe1\x03\n\x0eGraphiteRollup\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12h\n\x08patterns\x18\x02 \x03(\x0b\x32N.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.GraphiteRollup.PatternB\x06\x82\xc8\x31\x02>0\x12\x18\n\x10path_column_name\x18\x03 \x01(\t\x12\x18\n\x10time_column_name\x18\x04 \x01(\t\x12\x19\n\x11value_column_name\x18\x05 \x01(\t\x12\x1b\n\x13version_column_name\x18\x06 \x01(\t\x1a\xe4\x01\n\x07Pattern\x12\x0e\n\x06regexp\x18\x01 \x01(\t\x12\x16\n\x08\x66unction\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12s\n\tretention\x18\x03 \x03(\x0b\x32X.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.GraphiteRollup.Pattern.RetentionB\x06\x82\xc8\x31\x02>0\x1a<\n\tRetention\x12\x14\n\x03\x61ge\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x19\n\tprecision\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x1aG\n\x10QueryMaskingRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x06regexp\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07replace\x18\x03 \x01(\t\x1a\x95\x02\n\nQueryCache\x12?\n\x11max_size_in_bytes\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x0bmax_entries\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x45\n\x17max_entry_size_in_bytes\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x44\n\x16max_entry_size_in_rows\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"d\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\t\n\x05TRACE\x10\x01\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\x0f\n\x0bINFORMATION\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\x8d\x02\n\x13\x43lickhouseConfigSet\x12W\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfigB\x04\xe8\xc7\x31\x01\x12L\n\x0buser_config\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig\x12O\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfigB\x81\x01\n)yandex.cloud.api.mdb.clickhouse.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1/config;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.config.clickhouse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.mdb.clickhouse.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1/config;clickhouse'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_avg_part_size_for_too_many_parts']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_avg_part_size_for_too_many_parts']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['min_age_to_force_merge_seconds']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['min_age_to_force_merge_seconds']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_selecting_sleep_ms']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_selecting_sleep_ms']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_max_block_size']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_max_block_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_merge_selecting_sleep_ms']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_merge_selecting_sleep_ms']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_cleanup_delay_period']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_cleanup_delay_period']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['max_poll_interval_ms']._options = None
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['max_poll_interval_ms']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['session_timeout_ms']._options = None
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['session_timeout_ms']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['settings']._options = None
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['settings']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['min_part_size']._options = None
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['min_part_size']._serialized_options = b'\372\3071\003>=1'
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['level']._options = None
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['level']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['value']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['url']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['url']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['format']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['format']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['host']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['host']._serialized_options = b'\350\3071\001\212\3101\005<=253'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['priority']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['priority']._serialized_options = b'\350\3071\001\372\3071\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['table']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['table']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['replicas']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['replicas']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['table']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['table']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['host']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['host']._serialized_options = b'\212\3101\005<=253'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['user']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['user']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['collection']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['collection']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['host']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['host']._serialized_options = b'\212\3101\005<=253'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['user']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['user']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['table']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['table']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['hosts']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['hosts']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['user']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['user']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['type']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY.fields_by_name['attributes']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY.fields_by_name['attributes']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE.fields_by_name['attributes']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE.fields_by_name['attributes']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT.fields_by_name['type']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['lifetime']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['lifetime']._serialized_options = b'\300\3011\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['source']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['structure']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['structure']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['layout']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['layout']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['age']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['age']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['precision']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['precision']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['function']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['function']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['retention']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['retention']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['patterns']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['patterns']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_QUERYMASKINGRULE.fields_by_name['regexp']._options = None
  _CLICKHOUSECONFIG_QUERYMASKINGRULE.fields_by_name['regexp']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_size_in_bytes']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_size_in_bytes']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entries']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entries']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_bytes']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_bytes']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_rows']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_rows']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['max_connections']._options = None
  _CLICKHOUSECONFIG.fields_by_name['max_connections']._serialized_options = b'\372\3071\004>=10'
  _CLICKHOUSECONFIG.fields_by_name['max_concurrent_queries']._options = None
  _CLICKHOUSECONFIG.fields_by_name['max_concurrent_queries']._serialized_options = b'\372\3071\004>=10'
  _CLICKHOUSECONFIG.fields_by_name['mark_cache_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['mark_cache_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['builtin_dictionaries_reload_interval']._options = None
  _CLICKHOUSECONFIG.fields_by_name['builtin_dictionaries_reload_interval']._serialized_options = b'\030\001'
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['background_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_merges_mutations_concurrency_ratio']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_merges_mutations_concurrency_ratio']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_fetches_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_fetches_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_move_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_move_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_distributed_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_distributed_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_buffer_flush_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_buffer_flush_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_message_broker_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_message_broker_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_common_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_common_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['query_masking_rules']._options = None
  _CLICKHOUSECONFIG.fields_by_name['query_masking_rules']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIGSET.fields_by_name['effective_config']._options = None
  _CLICKHOUSECONFIGSET.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_CLICKHOUSECONFIG']._serialized_start=161
  _globals['_CLICKHOUSECONFIG']._serialized_end=13938
  _globals['_CLICKHOUSECONFIG_MERGETREE']._serialized_start=5126
  _globals['_CLICKHOUSECONFIG_MERGETREE']._serialized_end=7130
  _globals['_CLICKHOUSECONFIG_KAFKA']._serialized_start=7133
  _globals['_CLICKHOUSECONFIG_KAFKA']._serialized_end=8829
  _globals['_CLICKHOUSECONFIG_KAFKA_SECURITYPROTOCOL']._serialized_start=7794
  _globals['_CLICKHOUSECONFIG_KAFKA_SECURITYPROTOCOL']._serialized_end=7977
  _globals['_CLICKHOUSECONFIG_KAFKA_SASLMECHANISM']._serialized_start=7980
  _globals['_CLICKHOUSECONFIG_KAFKA_SASLMECHANISM']._serialized_end=8148
  _globals['_CLICKHOUSECONFIG_KAFKA_DEBUG']._serialized_start=8151
  _globals['_CLICKHOUSECONFIG_KAFKA_DEBUG']._serialized_end=8560
  _globals['_CLICKHOUSECONFIG_KAFKA_AUTOOFFSETRESET']._serialized_start=8563
  _globals['_CLICKHOUSECONFIG_KAFKA_AUTOOFFSETRESET']._serialized_end=8829
  _globals['_CLICKHOUSECONFIG_KAFKATOPIC']._serialized_start=8831
  _globals['_CLICKHOUSECONFIG_KAFKATOPIC']._serialized_end=8950
  _globals['_CLICKHOUSECONFIG_RABBITMQ']._serialized_start=8952
  _globals['_CLICKHOUSECONFIG_RABBITMQ']._serialized_end=9013
  _globals['_CLICKHOUSECONFIG_COMPRESSION']._serialized_start=9016
  _globals['_CLICKHOUSECONFIG_COMPRESSION']._serialized_end=9288
  _globals['_CLICKHOUSECONFIG_COMPRESSION_METHOD']._serialized_start=9237
  _globals['_CLICKHOUSECONFIG_COMPRESSION_METHOD']._serialized_end=9288
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY']._serialized_start=9291
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY']._serialized_end=12999
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE']._serialized_start=10266
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE']._serialized_end=10481
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER']._serialized_start=10432
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER']._serialized_end=10481
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE']._serialized_start=10484
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE']._serialized_end=10995
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA']._serialized_start=10868
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA']._serialized_end=10995
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE']._serialized_start=10998
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE']._serialized_end=11204
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE']._serialized_start=11207
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE']._serialized_end=11373
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE']._serialized_start=11376
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE']._serialized_end=11771
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE_SSLMODE']._serialized_start=11668
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE_SSLMODE']._serialized_end=11771
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE']._serialized_start=11774
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE']._serialized_end=12636
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE']._serialized_start=12346
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE']._serialized_end=12478
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID']._serialized_start=12480
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID']._serialized_end=12504
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY']._serialized_start=12507
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY']._serialized_end=12636
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT']._serialized_start=12639
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT']._serialized_end=12930
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT_TYPE']._serialized_start=12804
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT_TYPE']._serialized_end=12930
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_RANGE']._serialized_start=12932
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_RANGE']._serialized_end=12965
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP']._serialized_start=13002
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP']._serialized_end=13483
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN']._serialized_start=13255
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN']._serialized_end=13483
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION']._serialized_start=13423
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION']._serialized_end=13483
  _globals['_CLICKHOUSECONFIG_QUERYMASKINGRULE']._serialized_start=13485
  _globals['_CLICKHOUSECONFIG_QUERYMASKINGRULE']._serialized_end=13556
  _globals['_CLICKHOUSECONFIG_QUERYCACHE']._serialized_start=13559
  _globals['_CLICKHOUSECONFIG_QUERYCACHE']._serialized_end=13836
  _globals['_CLICKHOUSECONFIG_LOGLEVEL']._serialized_start=13838
  _globals['_CLICKHOUSECONFIG_LOGLEVEL']._serialized_end=13938
  _globals['_CLICKHOUSECONFIGSET']._serialized_start=13941
  _globals['_CLICKHOUSECONFIGSET']._serialized_end=14210
# @@protoc_insertion_point(module_scope)
