"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExpirationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ExpirationPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ExpirationPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExpirationConfig._ExpirationPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EXPIRATION_POLICY_UNSPECIFIED: ExpirationConfig._ExpirationPolicy.ValueType  # 0
        STATIC: ExpirationConfig._ExpirationPolicy.ValueType  # 1
        SINCE_LAST_ACTIVE: ExpirationConfig._ExpirationPolicy.ValueType  # 2

    class ExpirationPolicy(_ExpirationPolicy, metaclass=_ExpirationPolicyEnumTypeWrapper): ...
    EXPIRATION_POLICY_UNSPECIFIED: ExpirationConfig.ExpirationPolicy.ValueType  # 0
    STATIC: ExpirationConfig.ExpirationPolicy.ValueType  # 1
    SINCE_LAST_ACTIVE: ExpirationConfig.ExpirationPolicy.ValueType  # 2

    EXPIRATION_POLICY_FIELD_NUMBER: builtins.int
    TTL_DAYS_FIELD_NUMBER: builtins.int
    expiration_policy: global___ExpirationConfig.ExpirationPolicy.ValueType
    ttl_days: builtins.int
    def __init__(
        self,
        *,
        expiration_policy: global___ExpirationConfig.ExpirationPolicy.ValueType = ...,
        ttl_days: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["expiration_policy", b"expiration_policy", "ttl_days", b"ttl_days"]) -> None: ...

global___ExpirationConfig = ExpirationConfig

@typing.final
class Error(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    code: builtins.int
    message: builtins.str
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "message", b"message"]) -> None: ...

global___Error = Error
