# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/ai/assistants/v1/common.proto\x12\x1dyandex.cloud.ai.assistants.v1\x1a\x1egoogle/protobuf/wrappers.proto\"Q\n\x17PromptTruncationOptions\x12\x36\n\x11max_prompt_tokens\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"w\n\x11\x43ompletionOptions\x12/\n\nmax_tokens\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0btemperature\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"a\n\x0fSearchIndexTool\x12\x18\n\x10search_index_ids\x18\x01 \x03(\t\x12\x34\n\x0fmax_num_results\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"Z\n\x04Tool\x12\x46\n\x0csearch_index\x18\x01 \x01(\x0b\x32..yandex.cloud.ai.assistants.v1.SearchIndexToolH\x00\x42\n\n\x08ToolTypeBq\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistants'
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_start=109
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_end=190
  _globals['_COMPLETIONOPTIONS']._serialized_start=192
  _globals['_COMPLETIONOPTIONS']._serialized_end=311
  _globals['_SEARCHINDEXTOOL']._serialized_start=313
  _globals['_SEARCHINDEXTOOL']._serialized_end=410
  _globals['_TOOL']._serialized_start=412
  _globals['_TOOL']._serialized_end=502
# @@protoc_insertion_point(module_scope)
