# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/threads/message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/ai/assistants/v1/threads/message.proto\x12%yandex.cloud.ai.assistants.v1.threads\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x02\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tthread_id\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x06\x61uthor\x18\x05 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Author\x12J\n\x06labels\x18\x06 \x03(\x0b\x32:.yandex.cloud.ai.assistants.v1.threads.Message.LabelsEntry\x12\x46\n\x07\x63ontent\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContent\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x0eMessageContent\x12\x43\n\x07\x63ontent\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.ai.assistants.v1.threads.ContentPart\"\x93\x02\n\x0bMessageData\x12=\n\x06\x61uthor\x18\x01 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Author\x12N\n\x06labels\x18\x02 \x03(\x0b\x32>.yandex.cloud.ai.assistants.v1.threads.MessageData.LabelsEntry\x12\x46\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContent\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x17\n\x04Text\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"V\n\x0b\x43ontentPart\x12;\n\x04text\x18\x01 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.threads.TextH\x00\x42\n\n\x08PartType\"\"\n\x06\x41uthor\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\tB~\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threadsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.threads.message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threads'
  _MESSAGE_LABELSENTRY._options = None
  _MESSAGE_LABELSENTRY._serialized_options = b'8\001'
  _MESSAGEDATA_LABELSENTRY._options = None
  _MESSAGEDATA_LABELSENTRY._serialized_options = b'8\001'
  _globals['_MESSAGE']._serialized_start=128
  _globals['_MESSAGE']._serialized_end=494
  _globals['_MESSAGE_LABELSENTRY']._serialized_start=449
  _globals['_MESSAGE_LABELSENTRY']._serialized_end=494
  _globals['_MESSAGECONTENT']._serialized_start=496
  _globals['_MESSAGECONTENT']._serialized_end=581
  _globals['_MESSAGEDATA']._serialized_start=584
  _globals['_MESSAGEDATA']._serialized_end=859
  _globals['_MESSAGEDATA_LABELSENTRY']._serialized_start=449
  _globals['_MESSAGEDATA_LABELSENTRY']._serialized_end=494
  _globals['_TEXT']._serialized_start=861
  _globals['_TEXT']._serialized_end=884
  _globals['_CONTENTPART']._serialized_start=886
  _globals['_CONTENTPART']._serialized_end=972
  _globals['_AUTHOR']._serialized_start=974
  _globals['_AUTHOR']._serialized_end=1008
# @@protoc_insertion_point(module_scope)
