# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/common/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/ai/common/common.proto\x12\x16yandex.cloud.ai.common\"\xd4\x01\n\x10\x45xpirationConfig\x12T\n\x11\x65xpiration_policy\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.ai.common.ExpirationConfig.ExpirationPolicy\x12\x10\n\x08ttl_days\x18\x02 \x01(\x03\"X\n\x10\x45xpirationPolicy\x12!\n\x1d\x45XPIRATION_POLICY_UNSPECIFIED\x10\x00\x12\n\n\x06STATIC\x10\x01\x12\x15\n\x11SINCE_LAST_ACTIVE\x10\x02\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\tB_\n\x1ayandex.cloud.api.ai.commonZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/common;commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.common.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.ai.commonZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/common;common'
  _globals['_EXPIRATIONCONFIG']._serialized_start=64
  _globals['_EXPIRATIONCONFIG']._serialized_end=276
  _globals['_EXPIRATIONCONFIG_EXPIRATIONPOLICY']._serialized_start=188
  _globals['_EXPIRATIONCONFIG_EXPIRATIONPOLICY']._serialized_end=276
  _globals['_ERROR']._serialized_start=278
  _globals['_ERROR']._serialized_end=316
# @@protoc_insertion_point(module_scope)
