"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.report.kpi_pb2
import yandex.cloud.loadtesting.api.v1.report.kpi_value_pb2
import yandex.cloud.loadtesting.api.v1.report.status_pb2
import yandex.cloud.loadtesting.api.v1.report.table.report_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTableReportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test for which report table will be returned."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___GetTableReportRequest = GetTableReportRequest

@typing.final
class GetTableReportResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CasesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    OVERALL_FIELD_NUMBER: builtins.int
    CASES_FIELD_NUMBER: builtins.int
    status: yandex.cloud.loadtesting.api.v1.report.status_pb2.Status.ValueType
    """Status of report table."""
    @property
    def overall(self) -> yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report:
        """Result for all test cases combined ("overall" test case)."""

    @property
    def cases(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report]:
        """Results for individual test cases, mapped as `case_name:report`."""

    def __init__(
        self,
        *,
        status: yandex.cloud.loadtesting.api.v1.report.status_pb2.Status.ValueType = ...,
        overall: yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report | None = ...,
        cases: collections.abc.Mapping[builtins.str, yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["overall", b"overall"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cases", b"cases", "overall", b"overall", "status", b"status"]) -> None: ...

global___GetTableReportResponse = GetTableReportResponse

@typing.final
class CalculateReportKpiValuesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    TEST_FILTER_FIELD_NUMBER: builtins.int
    TEST_CASE_FIELD_NUMBER: builtins.int
    KPI_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder containing tests."""
    test_filter: builtins.str
    """Test filter selector to calculate KPI values for."""
    test_case: builtins.str
    """Test case to calculate KPI values for.

    If not specified, KPI values will be calculated for 'overall' case.
    """
    @property
    def kpi(self) -> yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi:
        """KPI to be calculated."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        test_filter: builtins.str = ...,
        test_case: builtins.str = ...,
        kpi: yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["kpi", b"kpi"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "kpi", b"kpi", "test_case", b"test_case", "test_filter", b"test_filter"]) -> None: ...

global___CalculateReportKpiValuesRequest = CalculateReportKpiValuesRequest

@typing.final
class CalculateReportKpiValuesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder."""
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.report.kpi_value_pb2.KpiValue]:
        """Actual KPI values."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        values: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.report.kpi_value_pb2.KpiValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "values", b"values"]) -> None: ...

global___CalculateReportKpiValuesResponse = CalculateReportKpiValuesResponse
