"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ConversationStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATION_BOUNDARIES_FIELD_NUMBER: builtins.int
    SPEAKER_STATISTICS_FIELD_NUMBER: builtins.int
    @property
    def conversation_boundaries(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries:
        """Audio segment boundaries"""

    @property
    def speaker_statistics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2.SpeakerStatistics]:
        """Average statistics for each speaker"""

    def __init__(
        self,
        *,
        conversation_boundaries: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries | None = ...,
        speaker_statistics: collections.abc.Iterable[yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2.SpeakerStatistics] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["conversation_boundaries", b"conversation_boundaries"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conversation_boundaries", b"conversation_boundaries", "speaker_statistics", b"speaker_statistics"]) -> None: ...

global___ConversationStatistics = ConversationStatistics
