# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/report/kpi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.common import quantiles_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_common_dot_quantiles__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/loadtesting/api/v1/report/kpi.proto\x12&yandex.cloud.loadtesting.api.v1.report\x1a\x36yandex/cloud/loadtesting/api/v1/common/quantiles.proto\"\x95\x01\n\x03Kpi\x12\x45\n\x08selector\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.loadtesting.api.v1.report.KpiSelector\x12G\n\tthreshold\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.report.KpiThreshold\"e\n\x0cKpiThreshold\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x46\n\ncomparison\x18\x02 \x01(\x0e\x32\x32.yandex.cloud.loadtesting.api.v1.report.Comparison\"\xcc\x08\n\x0bKpiSelector\x12Y\n\rresponse_time\x18\x01 \x01(\x0b\x32@.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ResponseTimeH\x00\x12R\n\tinstances\x18\x02 \x01(\x0b\x32=.yandex.cloud.loadtesting.api.v1.report.KpiSelector.InstancesH\x00\x12Y\n\rimbalance_rps\x18\x03 \x01(\x0b\x32@.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ImbalanceRpsH\x00\x12l\n\x17protocol_codes_absolute\x18\x04 \x01(\x0b\x32I.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ProtocolCodesAbsoluteH\x00\x12l\n\x17protocol_codes_relative\x18\x05 \x01(\x0b\x32I.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ProtocolCodesRelativeH\x00\x12j\n\x16network_codes_absolute\x18\x06 \x01(\x0b\x32H.yandex.cloud.loadtesting.api.v1.report.KpiSelector.NetworkCodesAbsoluteH\x00\x12j\n\x16network_codes_relative\x18\x07 \x01(\x0b\x32H.yandex.cloud.loadtesting.api.v1.report.KpiSelector.NetworkCodesRelativeH\x00\x1aV\n\x0cResponseTime\x12\x46\n\x08quantile\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.loadtesting.api.v1.common.QuantileType\x1aM\n\tInstances\x12@\n\x03\x61gg\x18\x01 \x01(\x0e\x32\x33.yandex.cloud.loadtesting.api.v1.report.Aggregation\x1a\x0e\n\x0cImbalanceRps\x1a/\n\x15ProtocolCodesAbsolute\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\t\x1a/\n\x15ProtocolCodesRelative\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\t\x1a.\n\x14NetworkCodesAbsolute\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\t\x1a.\n\x14NetworkCodesRelative\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\tB\x06\n\x04kind*\x9a\x01\n\x0b\x41ggregation\x12\x1b\n\x17\x41GGREGATION_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x41GGREGATION_MIN\x10\x01\x12\x13\n\x0f\x41GGREGATION_MAX\x10\x02\x12\x13\n\x0f\x41GGREGATION_AVG\x10\x04\x12\x16\n\x12\x41GGREGATION_MEDIAN\x10\x05\x12\x17\n\x13\x41GGREGATION_STD_DEV\x10\x06*v\n\nComparison\x12\x1a\n\x16\x43OMPARISON_UNSPECIFIED\x10\x00\x12\x11\n\rCOMPARISON_LT\x10\x01\x12\x12\n\x0e\x43OMPARISON_LTE\x10\x02\x12\x11\n\rCOMPARISON_GT\x10\x03\x12\x12\n\x0e\x43OMPARISON_GTE\x10\x04\x42\x7f\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;reportb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.report.kpi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;report'
  _globals['_AGGREGATION']._serialized_start=1507
  _globals['_AGGREGATION']._serialized_end=1661
  _globals['_COMPARISON']._serialized_start=1663
  _globals['_COMPARISON']._serialized_end=1781
  _globals['_KPI']._serialized_start=149
  _globals['_KPI']._serialized_end=298
  _globals['_KPITHRESHOLD']._serialized_start=300
  _globals['_KPITHRESHOLD']._serialized_end=401
  _globals['_KPISELECTOR']._serialized_start=404
  _globals['_KPISELECTOR']._serialized_end=1504
  _globals['_KPISELECTOR_RESPONSETIME']._serialized_start=1121
  _globals['_KPISELECTOR_RESPONSETIME']._serialized_end=1207
  _globals['_KPISELECTOR_INSTANCES']._serialized_start=1209
  _globals['_KPISELECTOR_INSTANCES']._serialized_end=1286
  _globals['_KPISELECTOR_IMBALANCERPS']._serialized_start=1288
  _globals['_KPISELECTOR_IMBALANCERPS']._serialized_end=1302
  _globals['_KPISELECTOR_PROTOCOLCODESABSOLUTE']._serialized_start=1304
  _globals['_KPISELECTOR_PROTOCOLCODESABSOLUTE']._serialized_end=1351
  _globals['_KPISELECTOR_PROTOCOLCODESRELATIVE']._serialized_start=1353
  _globals['_KPISELECTOR_PROTOCOLCODESRELATIVE']._serialized_end=1400
  _globals['_KPISELECTOR_NETWORKCODESABSOLUTE']._serialized_start=1402
  _globals['_KPISELECTOR_NETWORKCODESABSOLUTE']._serialized_end=1448
  _globals['_KPISELECTOR_NETWORKCODESRELATIVE']._serialized_start=1450
  _globals['_KPISELECTOR_NETWORKCODESRELATIVE']._serialized_end=1496
# @@protoc_insertion_point(module_scope)
