"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TranslatedText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    DETECTED_LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Translated text."""
    detected_language_code: builtins.str
    """The language code of the source text.
    Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` en ``).
    """
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        detected_language_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["detected_language_code", b"detected_language_code", "text", b"text"]) -> None: ...

global___TranslatedText = TranslatedText

@typing.final
class Language(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    code: builtins.str
    """The language code.
    Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` en ``).
    """
    name: builtins.str
    """The name of the language (for example, `` English ``)."""
    def __init__(
        self,
        *,
        code: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "name", b"name"]) -> None: ...

global___Language = Language
