# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/backend_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import backend_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/apploadbalancer/v1/backend_group_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x33yandex/cloud/apploadbalancer/v1/backend_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x16GetBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x18ListBackendGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"{\n\x19ListBackendGroupsResponse\x12\x45\n\x0e\x62\x61\x63kend_groups\x18\x01 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.BackendGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x19\x44\x65leteBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1a\x44\x65leteBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\xed\x04\n\x19UpdateBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x41\n\x04http\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x12\x45\n\x06stream\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.StreamBackendGroupH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01\"6\n\x1aUpdateBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\xaf\x04\n\x19\x43reateBackendGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x41\n\x04http\x18\x05 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x12\x45\n\x06stream\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.StreamBackendGroupH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x62\x61\x63kend\"6\n\x1a\x43reateBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\x88\x02\n\x11\x41\x64\x64\x42\x61\x63kendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\x04http\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackendH\x00\x12<\n\x04grpc\x18\x03 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackendH\x00\x12@\n\x06stream\x18\x05 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackendH\x00\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01J\x04\x08\x04\x10\x05\"D\n\x12\x41\x64\x64\x42\x61\x63kendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"\xb6\x02\n\x14UpdateBackendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04http\x18\x03 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackendH\x00\x12<\n\x04grpc\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackendH\x00\x12@\n\x06stream\x18\x05 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackendH\x00\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01\"G\n\x15UpdateBackendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"R\n\x14RemoveBackendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"G\n\x15RemoveBackendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"\x89\x01\n!ListBackendGroupOperationsRequest\x12&\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListBackendGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf1\x0e\n\x13\x42\x61\x63kendGroupService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.apploadbalancer.v1.GetBackendGroupRequest\x1a-.yandex.cloud.apploadbalancer.v1.BackendGroup\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/apploadbalancer/v1/backendGroups/{backend_group_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest\x1a:.yandex.cloud.apploadbalancer.v1.ListBackendGroupsResponse\")\x82\xd3\xe4\x93\x02#\x12!/apploadbalancer/v1/backendGroups\x12\xc3\x01\n\x06\x43reate\x12:.yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2**\n\x1a\x43reateBackendGroupMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02&\"!/apploadbalancer/v1/backendGroups:\x01*\x12\xd6\x01\n\x06Update\x12:.yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2**\n\x1aUpdateBackendGroupMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02\x39\x32\x34/apploadbalancer/v1/backendGroups/{backend_group_id}:\x01*\x12\xdc\x01\n\x06\x44\x65lete\x12:.yandex.cloud.apploadbalancer.v1.DeleteBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*3\n\x1a\x44\x65leteBackendGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/apploadbalancer/v1/backendGroups/{backend_group_id}\x12\xd5\x01\n\nAddBackend\x12\x32.yandex.cloud.apploadbalancer.v1.AddBackendRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*\"\n\x12\x41\x64\x64\x42\x61\x63kendMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02\x44\"?/apploadbalancer/v1/backendGroups/{backend_group_id}:addBackend:\x01*\x12\xe1\x01\n\rRemoveBackend\x12\x35.yandex.cloud.apploadbalancer.v1.RemoveBackendRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*%\n\x15RemoveBackendMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:removeBackend:\x01*\x12\xe1\x01\n\rUpdateBackend\x12\x35.yandex.cloud.apploadbalancer.v1.UpdateBackendRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*%\n\x15UpdateBackendMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:updateBackend:\x01*\x12\xe2\x01\n\x0eListOperations\x12\x42.yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest\x1a\x43.yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/apploadbalancer/v1/backendGroups/{backend_group_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _GETBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
  _GETBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _DELETEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
  _DELETEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _UPDATEBACKENDGROUPREQUEST_LABELSENTRY._options = None
  _UPDATEBACKENDGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend']._options = None
  _UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend']._serialized_options = b'\300\3011\001'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEBACKENDGROUPREQUEST_LABELSENTRY._options = None
  _CREATEBACKENDGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['folder_id']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['name']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['description']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _ADDBACKENDREQUEST.oneofs_by_name['backend']._options = None
  _ADDBACKENDREQUEST.oneofs_by_name['backend']._serialized_options = b'\300\3011\001'
  _ADDBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
  _ADDBACKENDREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _UPDATEBACKENDREQUEST.oneofs_by_name['backend']._options = None
  _UPDATEBACKENDREQUEST.oneofs_by_name['backend']._serialized_options = b'\300\3011\001'
  _UPDATEBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
  _UPDATEBACKENDREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _REMOVEBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
  _REMOVEBACKENDREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _REMOVEBACKENDREQUEST.fields_by_name['backend_name']._options = None
  _REMOVEBACKENDREQUEST.fields_by_name['backend_name']._serialized_options = b'\350\3071\001'
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['backend_group_id']._options = None
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _BACKENDGROUPSERVICE.methods_by_name['Get']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/apploadbalancer/v1/backendGroups/{backend_group_id}'
  _BACKENDGROUPSERVICE.methods_by_name['List']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/apploadbalancer/v1/backendGroups'
  _BACKENDGROUPSERVICE.methods_by_name['Create']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateBackendGroupMetadata\022\014BackendGroup\202\323\344\223\002&\"!/apploadbalancer/v1/backendGroups:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['Update']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateBackendGroupMetadata\022\014BackendGroup\202\323\344\223\002924/apploadbalancer/v1/backendGroups/{backend_group_id}:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['Delete']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteBackendGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/apploadbalancer/v1/backendGroups/{backend_group_id}'
  _BACKENDGROUPSERVICE.methods_by_name['AddBackend']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['AddBackend']._serialized_options = b'\262\322*\"\n\022AddBackendMetadata\022\014BackendGroup\202\323\344\223\002D\"?/apploadbalancer/v1/backendGroups/{backend_group_id}:addBackend:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['RemoveBackend']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['RemoveBackend']._serialized_options = b'\262\322*%\n\025RemoveBackendMetadata\022\014BackendGroup\202\323\344\223\002G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:removeBackend:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['UpdateBackend']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['UpdateBackend']._serialized_options = b'\262\322*%\n\025UpdateBackendMetadata\022\014BackendGroup\202\323\344\223\002G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:updateBackend:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002A\022?/apploadbalancer/v1/backendGroups/{backend_group_id}/operations'
  _globals['_GETBACKENDGROUPREQUEST']._serialized_start=318
  _globals['_GETBACKENDGROUPREQUEST']._serialized_end=374
  _globals['_LISTBACKENDGROUPSREQUEST']._serialized_start=377
  _globals['_LISTBACKENDGROUPSREQUEST']._serialized_end=518
  _globals['_LISTBACKENDGROUPSRESPONSE']._serialized_start=520
  _globals['_LISTBACKENDGROUPSRESPONSE']._serialized_end=643
  _globals['_DELETEBACKENDGROUPREQUEST']._serialized_start=645
  _globals['_DELETEBACKENDGROUPREQUEST']._serialized_end=704
  _globals['_DELETEBACKENDGROUPMETADATA']._serialized_start=706
  _globals['_DELETEBACKENDGROUPMETADATA']._serialized_end=760
  _globals['_UPDATEBACKENDGROUPREQUEST']._serialized_start=763
  _globals['_UPDATEBACKENDGROUPREQUEST']._serialized_end=1384
  _globals['_UPDATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_start=1322
  _globals['_UPDATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_end=1367
  _globals['_UPDATEBACKENDGROUPMETADATA']._serialized_start=1386
  _globals['_UPDATEBACKENDGROUPMETADATA']._serialized_end=1440
  _globals['_CREATEBACKENDGROUPREQUEST']._serialized_start=1443
  _globals['_CREATEBACKENDGROUPREQUEST']._serialized_end=2002
  _globals['_CREATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_start=1322
  _globals['_CREATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_end=1367
  _globals['_CREATEBACKENDGROUPMETADATA']._serialized_start=2004
  _globals['_CREATEBACKENDGROUPMETADATA']._serialized_end=2058
  _globals['_ADDBACKENDREQUEST']._serialized_start=2061
  _globals['_ADDBACKENDREQUEST']._serialized_end=2325
  _globals['_ADDBACKENDMETADATA']._serialized_start=2327
  _globals['_ADDBACKENDMETADATA']._serialized_end=2395
  _globals['_UPDATEBACKENDREQUEST']._serialized_start=2398
  _globals['_UPDATEBACKENDREQUEST']._serialized_end=2708
  _globals['_UPDATEBACKENDMETADATA']._serialized_start=2710
  _globals['_UPDATEBACKENDMETADATA']._serialized_end=2781
  _globals['_REMOVEBACKENDREQUEST']._serialized_start=2783
  _globals['_REMOVEBACKENDREQUEST']._serialized_end=2865
  _globals['_REMOVEBACKENDMETADATA']._serialized_start=2867
  _globals['_REMOVEBACKENDMETADATA']._serialized_end=2938
  _globals['_LISTBACKENDGROUPOPERATIONSREQUEST']._serialized_start=2941
  _globals['_LISTBACKENDGROUPOPERATIONSREQUEST']._serialized_end=3078
  _globals['_LISTBACKENDGROUPOPERATIONSRESPONSE']._serialized_start=3080
  _globals['_LISTBACKENDGROUPOPERATIONSRESPONSE']._serialized_end=3196
  _globals['_BACKENDGROUPSERVICE']._serialized_start=3199
  _globals['_BACKENDGROUPSERVICE']._serialized_end=5104
# @@protoc_insertion_point(module_scope)
