# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/analysis/conversation_statistics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1.analysis import statistics_common_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_statistics__common__pb2
from yandex.cloud.speechsense.v1.analysis import speaker_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_speaker__statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/speechsense/v1/analysis/conversation_statistics.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\x1a=yandex/cloud/speechsense/v1/analysis/speaker_statistics.proto\"\xcc\x01\n\x16\x43onversationStatistics\x12]\n\x17\x63onversation_boundaries\x18\x01 \x01(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.AudioSegmentBoundaries\x12S\n\x12speaker_statistics\x18\x02 \x03(\x0b\x32\x37.yandex.cloud.speechsense.v1.analysis.SpeakerStatisticsB\x9d\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x1b\x43onversationStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\033ConversationStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_CONVERSATIONSTATISTICS']._serialized_start=234
  _globals['_CONVERSATIONSTATISTICS']._serialized_end=438
# @@protoc_insertion_point(module_scope)
