# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/eventrouter/v1/rule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/serverless/eventrouter/v1/rule.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe4\x04\n\x04Rule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12H\n\x06labels\x18\x08 \x03(\x0b\x32\x38.yandex.cloud.serverless.eventrouter.v1.Rule.LabelsEntry\x12>\n\x06\x66ilter\x18\x0b \x01(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.Filter\x12H\n\x07targets\x18\x0c \x03(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.TargetB\x07\x82\xc8\x31\x03\x31-5\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x43\n\x06status\x18\x0e \x01(\x0e\x32\x33.yandex.cloud.serverless.eventrouter.v1.Rule.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"<\n\x06\x46ilter\x12\x1f\n\tjq_filter\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1024H\x00\x42\x11\n\tcondition\x12\x04\xc0\xc1\x31\x01\"I\n\x0bTransformer\x12%\n\x0ejq_transformer\x18\x01 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536H\x00\x42\x13\n\x0btransformer\x12\x04\xc0\xc1\x31\x01\"\x8a\x08\n\x06Target\x12@\n\x03yds\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.serverless.eventrouter.v1.YdsTargetH\x00\x12@\n\x03ymq\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.serverless.eventrouter.v1.YmqTargetH\x00\x12J\n\x08\x66unction\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.serverless.eventrouter.v1.FunctionTargetH\x00\x12L\n\tcontainer\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.serverless.eventrouter.v1.ContainerTargetH\x00\x12g\n\x14gateway_ws_broadcast\x18\x05 \x01(\x0b\x32G.yandex.cloud.serverless.eventrouter.v1.GatewayWebsocketBroadcastTargetH\x00\x12H\n\x07logging\x18\x06 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.LoggingTargetH\x00\x12J\n\x08workflow\x18\x07 \x01(\x0b\x32\x36.yandex.cloud.serverless.eventrouter.v1.WorkflowTargetH\x00\x12H\n\x0btransformer\x18\x32 \x01(\x0b\x32\x33.yandex.cloud.serverless.eventrouter.v1.Transformer\x12M\n\x0eretry_settings\x18\x33 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.RetrySettings\x12T\n\x11\x64\x65\x61\x64_letter_queue\x18\x34 \x01(\x0b\x32\x37.yandex.cloud.serverless.eventrouter.v1.PutQueueMessageH\x01\x12\x45\n\x06status\x18\x36 \x01(\x0e\x32\x35.yandex.cloud.serverless.eventrouter.v1.Target.Status\"\x81\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x16\n\x12RESOURCE_NOT_FOUND\x10\x03\x12\x15\n\x11PERMISSION_DENIED\x10\x04\x12\x15\n\x11SUBJECT_NOT_FOUND\x10\x05\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\x42\r\n\x0b\x64\x65\x61\x64_letterJ\x04\x08\x08\x10\x32J\x04\x08\x35\x10\x36\"h\n\tYdsTarget\x12\x16\n\x08\x64\x61tabase\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bstream_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"N\n\tYmqTarget\x12\x17\n\tqueue_arn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xbe\x01\n\x0e\x46unctionTarget\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12$\n\x12service_account_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettings\"\xd7\x01\n\x0f\x43ontainerTarget\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x15\x63ontainer_revision_id\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12$\n\x12service_account_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettings\"\xd0\x01\n\x1fGatewayWebsocketBroadcastTarget\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettings\"\x8f\x01\n\rLoggingTarget\x12 \n\x0clog_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=63H\x00\x12\x1d\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=63H\x00\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50B\x13\n\x0b\x64\x65stination\x12\x04\xc0\xc1\x31\x01\"\xb8\x01\n\x0eWorkflowTarget\x12!\n\x0bworkflow_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x12service_account_id\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettingsJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"l\n\rRetrySettings\x12 \n\x0eretry_attempts\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12\x39\n\x0bmaximum_age\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=24h\"N\n\x0fPutQueueMessage\x12\x11\n\tqueue_arn\x18\x01 \x01(\t\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x88\x01\n\rBatchSettings\x12\x1d\n\tmax_count\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1f\n\tmax_bytes\x18\x02 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x30-262144\x12\x37\n\x06\x63utoff\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xe8\xc7\x31\x01\xfa\xc7\x31\x04<=1mB\x8a\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x04PERRZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.rule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\004PERRZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _RULE_LABELSENTRY._options = None
  _RULE_LABELSENTRY._serialized_options = b'8\001'
  _RULE.fields_by_name['targets']._options = None
  _RULE.fields_by_name['targets']._serialized_options = b'\202\3101\0031-5'
  _FILTER.oneofs_by_name['condition']._options = None
  _FILTER.oneofs_by_name['condition']._serialized_options = b'\300\3011\001'
  _FILTER.fields_by_name['jq_filter']._options = None
  _FILTER.fields_by_name['jq_filter']._serialized_options = b'\212\3101\006<=1024'
  _TRANSFORMER.oneofs_by_name['transformer']._options = None
  _TRANSFORMER.oneofs_by_name['transformer']._serialized_options = b'\300\3011\001'
  _TRANSFORMER.fields_by_name['jq_transformer']._options = None
  _TRANSFORMER.fields_by_name['jq_transformer']._serialized_options = b'\212\3101\007<=65536'
  _TARGET.oneofs_by_name['target']._options = None
  _TARGET.oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _YDSTARGET.fields_by_name['database']._options = None
  _YDSTARGET.fields_by_name['database']._serialized_options = b'\350\3071\001'
  _YDSTARGET.fields_by_name['stream_name']._options = None
  _YDSTARGET.fields_by_name['stream_name']._serialized_options = b'\350\3071\001'
  _YDSTARGET.fields_by_name['service_account_id']._options = None
  _YDSTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _YMQTARGET.fields_by_name['queue_arn']._options = None
  _YMQTARGET.fields_by_name['queue_arn']._serialized_options = b'\350\3071\001'
  _YMQTARGET.fields_by_name['service_account_id']._options = None
  _YMQTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _FUNCTIONTARGET.fields_by_name['function_id']._options = None
  _FUNCTIONTARGET.fields_by_name['function_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _FUNCTIONTARGET.fields_by_name['service_account_id']._options = None
  _FUNCTIONTARGET.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CONTAINERTARGET.fields_by_name['container_id']._options = None
  _CONTAINERTARGET.fields_by_name['container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CONTAINERTARGET.fields_by_name['service_account_id']._options = None
  _CONTAINERTARGET.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['gateway_id']._options = None
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['path']._options = None
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['path']._serialized_options = b'\350\3071\001'
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['service_account_id']._options = None
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LOGGINGTARGET.oneofs_by_name['destination']._options = None
  _LOGGINGTARGET.oneofs_by_name['destination']._serialized_options = b'\300\3011\001'
  _LOGGINGTARGET.fields_by_name['log_group_id']._options = None
  _LOGGINGTARGET.fields_by_name['log_group_id']._serialized_options = b'\212\3101\004<=63'
  _LOGGINGTARGET.fields_by_name['folder_id']._options = None
  _LOGGINGTARGET.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=63'
  _LOGGINGTARGET.fields_by_name['service_account_id']._options = None
  _LOGGINGTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _WORKFLOWTARGET.fields_by_name['workflow_id']._options = None
  _WORKFLOWTARGET.fields_by_name['workflow_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _WORKFLOWTARGET.fields_by_name['service_account_id']._options = None
  _WORKFLOWTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RETRYSETTINGS.fields_by_name['retry_attempts']._options = None
  _RETRYSETTINGS.fields_by_name['retry_attempts']._serialized_options = b'\372\3071\0040-10'
  _RETRYSETTINGS.fields_by_name['maximum_age']._options = None
  _RETRYSETTINGS.fields_by_name['maximum_age']._serialized_options = b'\372\3071\005<=24h'
  _PUTQUEUEMESSAGE.fields_by_name['service_account_id']._options = None
  _PUTQUEUEMESSAGE.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHSETTINGS.fields_by_name['max_count']._options = None
  _BATCHSETTINGS.fields_by_name['max_count']._serialized_options = b'\372\3071\0060-1000'
  _BATCHSETTINGS.fields_by_name['max_bytes']._options = None
  _BATCHSETTINGS.fields_by_name['max_bytes']._serialized_options = b'\372\3071\0100-262144'
  _BATCHSETTINGS.fields_by_name['cutoff']._options = None
  _BATCHSETTINGS.fields_by_name['cutoff']._serialized_options = b'\350\3071\001\372\3071\004<=1m'
  _globals['_RULE']._serialized_start=190
  _globals['_RULE']._serialized_end=802
  _globals['_RULE_LABELSENTRY']._serialized_start=656
  _globals['_RULE_LABELSENTRY']._serialized_end=701
  _globals['_RULE_STATUS']._serialized_start=703
  _globals['_RULE_STATUS']._serialized_end=790
  _globals['_FILTER']._serialized_start=804
  _globals['_FILTER']._serialized_end=864
  _globals['_TRANSFORMER']._serialized_start=866
  _globals['_TRANSFORMER']._serialized_end=939
  _globals['_TARGET']._serialized_start=942
  _globals['_TARGET']._serialized_end=1976
  _globals['_TARGET_STATUS']._serialized_start=1804
  _globals['_TARGET_STATUS']._serialized_end=1933
  _globals['_YDSTARGET']._serialized_start=1978
  _globals['_YDSTARGET']._serialized_end=2082
  _globals['_YMQTARGET']._serialized_start=2084
  _globals['_YMQTARGET']._serialized_end=2162
  _globals['_FUNCTIONTARGET']._serialized_start=2165
  _globals['_FUNCTIONTARGET']._serialized_end=2355
  _globals['_CONTAINERTARGET']._serialized_start=2358
  _globals['_CONTAINERTARGET']._serialized_end=2573
  _globals['_GATEWAYWEBSOCKETBROADCASTTARGET']._serialized_start=2576
  _globals['_GATEWAYWEBSOCKETBROADCASTTARGET']._serialized_end=2784
  _globals['_LOGGINGTARGET']._serialized_start=2787
  _globals['_LOGGINGTARGET']._serialized_end=2930
  _globals['_WORKFLOWTARGET']._serialized_start=2933
  _globals['_WORKFLOWTARGET']._serialized_end=3117
  _globals['_RETRYSETTINGS']._serialized_start=3119
  _globals['_RETRYSETTINGS']._serialized_end=3227
  _globals['_PUTQUEUEMESSAGE']._serialized_start=3229
  _globals['_PUTQUEUEMESSAGE']._serialized_end=3307
  _globals['_BATCHSETTINGS']._serialized_start=3310
  _globals['_BATCHSETTINGS']._serialized_end=3446
# @@protoc_insertion_point(module_scope)
