"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PurgeCacheRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to perform purge operation on."""
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Set of paths:
        Paths of the files to remove from the cache.

        You may use asterisk (`*`) as a wildcard character that substitutes any number of characters.

        If an empty array of paths is specified (`"paths": []`), the cache is purged entirely.
        """

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["paths", b"paths", "resource_id", b"resource_id"]) -> None: ...

global___PurgeCacheRequest = PurgeCacheRequest

@typing.final
class PurgeCacheMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___PurgeCacheMetadata = PurgeCacheMetadata

@typing.final
class PrefetchCacheRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to perform prefetch operation on."""
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Set of paths to prefetch."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["paths", b"paths", "resource_id", b"resource_id"]) -> None: ...

global___PrefetchCacheRequest = PrefetchCacheRequest

@typing.final
class PrefetchCacheMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___PrefetchCacheMetadata = PrefetchCacheMetadata
