"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.elasticsearch.v1.extension_pb2
import yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ExtensionServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.GetExtensionRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension,
    ]
    """Returns the specified extension of Elasticsearch cluster."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse,
    ]
    """Returns the list of available extensions for the specified Elasticsearch cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.CreateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new extension version."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.UpdateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified extension."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.DeleteExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified extension."""

class ExtensionServiceAsyncStub:
    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.GetExtensionRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension,
    ]
    """Returns the specified extension of Elasticsearch cluster."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsRequest,
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse,
    ]
    """Returns the list of available extensions for the specified Elasticsearch cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.CreateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new extension version."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.UpdateExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified extension."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.DeleteExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified extension."""

class ExtensionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.GetExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension, collections.abc.Awaitable[yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension]]:
        """Returns the specified extension of Elasticsearch cluster."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse, collections.abc.Awaitable[yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.ListExtensionsResponse]]:
        """Returns the list of available extensions for the specified Elasticsearch cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.CreateExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates new extension version."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.UpdateExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified extension."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2.DeleteExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified extension."""

def add_ExtensionServiceServicer_to_server(servicer: ExtensionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
