"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.clickhouse.v1.version_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListVersionsResponse.next_page_token] that can be used
    to get the next page of results in subsequent ListVersions requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token] to the [ListVersionsResponse.next_page_token] returned by a previous ListVersions
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListVersionsRequest = ListVersionsRequest

@typing.final
class ListVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListVersions requests,
    if the number of results is larger than [ListVersionsRequest.page_size] specified in the request.
    To get the next page, specify the value of [next_page_token] as a value for
    the [ListVersionsRequest.page_token] parameter in the next ListVerions request. Subsequent ListVersions
    requests will have their own [next_page_token] to continue paging through the results.
    """
    @property
    def version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.version_pb2.Version]:
        """Requested list of available versions."""

    def __init__(
        self,
        *,
        version: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.version_pb2.Version] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "version", b"version"]) -> None: ...

global___ListVersionsResponse = ListVersionsResponse
