# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/audio.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/speechsense/v1/audio.proto\x12\x1byandex.cloud.speechsense.v1\"\xe1\x01\n\x08RawAudio\x12K\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32\x33.yandex.cloud.speechsense.v1.RawAudio.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x03\x12\x1b\n\x13\x61udio_channel_count\x18\x03 \x01(\x03\"P\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41UDIO_ENCODING_LINEAR16_PCM\x10\x01\"\x8a\x02\n\x0e\x43ontainerAudio\x12\\\n\x14\x63ontainer_audio_type\x18\x01 \x01(\x0e\x32>.yandex.cloud.speechsense.v1.ContainerAudio.ContainerAudioType\"\x99\x01\n\x12\x43ontainerAudioType\x12$\n CONTAINER_AUDIO_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONTAINER_AUDIO_TYPE_WAV\x10\x01\x12!\n\x1d\x43ONTAINER_AUDIO_TYPE_OGG_OPUS\x10\x02\x12\x1c\n\x18\x43ONTAINER_AUDIO_TYPE_MP3\x10\x03\"\xa2\x01\n\rAudioMetadata\x12:\n\traw_audio\x18\x01 \x01(\x0b\x32%.yandex.cloud.speechsense.v1.RawAudioH\x00\x12\x46\n\x0f\x63ontainer_audio\x18\x02 \x01(\x0b\x32+.yandex.cloud.speechsense.v1.ContainerAudioH\x00\x42\r\n\x0b\x41udioFormat\"\x1a\n\nAudioChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\xa5\x01\n\x15\x41udioStreamingRequest\x12\x44\n\x0e\x61udio_metadata\x18\x01 \x01(\x0b\x32*.yandex.cloud.speechsense.v1.AudioMetadataH\x00\x12\x38\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\'.yandex.cloud.speechsense.v1.AudioChunkH\x00\x42\x0c\n\nAudioEvent\"\x8f\x01\n\x0c\x41udioRequest\x12\x42\n\x0e\x61udio_metadata\x18\x01 \x01(\x0b\x32*.yandex.cloud.speechsense.v1.AudioMetadata\x12;\n\naudio_data\x18\x02 \x01(\x0b\x32\'.yandex.cloud.speechsense.v1.AudioChunkBz\n\x1fyandex.cloud.api.speechsense.v1B\nAudioProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.audio_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\nAudioProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_RAWAUDIO']._serialized_start=73
  _globals['_RAWAUDIO']._serialized_end=298
  _globals['_RAWAUDIO_AUDIOENCODING']._serialized_start=218
  _globals['_RAWAUDIO_AUDIOENCODING']._serialized_end=298
  _globals['_CONTAINERAUDIO']._serialized_start=301
  _globals['_CONTAINERAUDIO']._serialized_end=567
  _globals['_CONTAINERAUDIO_CONTAINERAUDIOTYPE']._serialized_start=414
  _globals['_CONTAINERAUDIO_CONTAINERAUDIOTYPE']._serialized_end=567
  _globals['_AUDIOMETADATA']._serialized_start=570
  _globals['_AUDIOMETADATA']._serialized_end=732
  _globals['_AUDIOCHUNK']._serialized_start=734
  _globals['_AUDIOCHUNK']._serialized_end=760
  _globals['_AUDIOSTREAMINGREQUEST']._serialized_start=763
  _globals['_AUDIOSTREAMINGREQUEST']._serialized_end=928
  _globals['_AUDIOREQUEST']._serialized_start=931
  _globals['_AUDIOREQUEST']._serialized_end=1074
# @@protoc_insertion_point(module_scope)
