# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/analysis/speaker_statistics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1.analysis import statistics_common_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_statistics__common__pb2
from yandex.cloud.speechsense.v1.analysis import utterance_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_utterance__statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/speechsense/v1/analysis/speaker_statistics.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\x1a?yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto\"\xb3\x03\n\x11SpeakerStatistics\x12\x13\n\x0bspeaker_tag\x18\x01 \x01(\t\x12V\n\x13\x63omplete_statistics\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.speechsense.v1.analysis.UtteranceStatistics\x12X\n\x13words_per_utterance\x18\x03 \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatistics\x12Z\n\x15letters_per_utterance\x18\x04 \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatistics\x12\x17\n\x0futterance_count\x18\x05 \x01(\x03\x12\x62\n\x1dutterance_duration_estimation\x18\x06 \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatisticsB\x98\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x16SpeakerStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\026SpeakerStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_SPEAKERSTATISTICS']._serialized_start=231
  _globals['_SPEAKERSTATISTICS']._serialized_end=666
# @@protoc_insertion_point(module_scope)
