# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/topic_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.kafka.v1 import topic_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/mdb/kafka/v1/topic_service.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a%yandex/cloud/mdb/kafka/v1/topic.proto\"h\n\x0fGetTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05\x31-256\"s\n\x11ListTopicsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"_\n\x12ListTopicsResponse\x12\x30\n\x06topics\x18\x01 \x03(\x0b\x32 .yandex.cloud.mdb.kafka.v1.Topic\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"v\n\x12\x43reateTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\ntopic_spec\x18\x02 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.TopicSpecB\x04\xe8\xc7\x31\x01\"^\n\x13\x43reateTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05<=256\"\xd6\x01\n\x12UpdateTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05\x31-256\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x38\n\ntopic_spec\x18\x04 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.TopicSpec\"=\n\x13UpdateTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ntopic_name\x18\x02 \x01(\t\"k\n\x12\x44\x65leteTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05\x31-256\"=\n\x13\x44\x65leteTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ntopic_name\x18\x02 \x01(\t2\x96\x07\n\x0cTopicService\x12\x98\x01\n\x03Get\x12*.yandex.cloud.mdb.kafka.v1.GetTopicRequest\x1a .yandex.cloud.mdb.kafka.v1.Topic\"C\x82\xd3\xe4\x93\x02=\x12;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}\x12\x9b\x01\n\x04List\x12,.yandex.cloud.mdb.kafka.v1.ListTopicsRequest\x1a-.yandex.cloud.mdb.kafka.v1.ListTopicsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./managed-kafka/v1/clusters/{cluster_id}/topics\x12\xb5\x01\n\x06\x43reate\x12-.yandex.cloud.mdb.kafka.v1.CreateTopicRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\x1c\n\x13\x43reateTopicMetadata\x12\x05Topic\x82\xd3\xe4\x93\x02\x33\"./managed-kafka/v1/clusters/{cluster_id}/topics:\x01*\x12\xc2\x01\n\x06Update\x12-.yandex.cloud.mdb.kafka.v1.UpdateTopicRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*\x1c\n\x13UpdateTopicMetadata\x12\x05Topic\x82\xd3\xe4\x93\x02@2;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}:\x01*\x12\xcf\x01\n\x06\x44\x65lete\x12-.yandex.cloud.mdb.kafka.v1.DeleteTopicRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*,\n\x13\x44\x65leteTopicMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=*;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}Bd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.topic_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _GETTOPICREQUEST.fields_by_name['cluster_id']._options = None
  _GETTOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETTOPICREQUEST.fields_by_name['topic_name']._options = None
  _GETTOPICREQUEST.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\0051-256'
  _LISTTOPICSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTTOPICSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTTOPICSREQUEST.fields_by_name['page_size']._options = None
  _LISTTOPICSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTTOPICSREQUEST.fields_by_name['page_token']._options = None
  _LISTTOPICSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATETOPICREQUEST.fields_by_name['cluster_id']._options = None
  _CREATETOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATETOPICREQUEST.fields_by_name['topic_spec']._options = None
  _CREATETOPICREQUEST.fields_by_name['topic_spec']._serialized_options = b'\350\3071\001'
  _CREATETOPICMETADATA.fields_by_name['topic_name']._options = None
  _CREATETOPICMETADATA.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\005<=256'
  _UPDATETOPICREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATETOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATETOPICREQUEST.fields_by_name['topic_name']._options = None
  _UPDATETOPICREQUEST.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\0051-256'
  _DELETETOPICREQUEST.fields_by_name['cluster_id']._options = None
  _DELETETOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETETOPICREQUEST.fields_by_name['topic_name']._options = None
  _DELETETOPICREQUEST.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\0051-256'
  _TOPICSERVICE.methods_by_name['Get']._options = None
  _TOPICSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002=\022;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}'
  _TOPICSERVICE.methods_by_name['List']._options = None
  _TOPICSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0020\022./managed-kafka/v1/clusters/{cluster_id}/topics'
  _TOPICSERVICE.methods_by_name['Create']._options = None
  _TOPICSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateTopicMetadata\022\005Topic\202\323\344\223\0023\"./managed-kafka/v1/clusters/{cluster_id}/topics:\001*'
  _TOPICSERVICE.methods_by_name['Update']._options = None
  _TOPICSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateTopicMetadata\022\005Topic\202\323\344\223\002@2;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}:\001*'
  _TOPICSERVICE.methods_by_name['Delete']._options = None
  _TOPICSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteTopicMetadata\022\025google.protobuf.Empty\202\323\344\223\002=*;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}'
  _globals['_GETTOPICREQUEST']._serialized_start=284
  _globals['_GETTOPICREQUEST']._serialized_end=388
  _globals['_LISTTOPICSREQUEST']._serialized_start=390
  _globals['_LISTTOPICSREQUEST']._serialized_end=505
  _globals['_LISTTOPICSRESPONSE']._serialized_start=507
  _globals['_LISTTOPICSRESPONSE']._serialized_end=602
  _globals['_CREATETOPICREQUEST']._serialized_start=604
  _globals['_CREATETOPICREQUEST']._serialized_end=722
  _globals['_CREATETOPICMETADATA']._serialized_start=724
  _globals['_CREATETOPICMETADATA']._serialized_end=818
  _globals['_UPDATETOPICREQUEST']._serialized_start=821
  _globals['_UPDATETOPICREQUEST']._serialized_end=1035
  _globals['_UPDATETOPICMETADATA']._serialized_start=1037
  _globals['_UPDATETOPICMETADATA']._serialized_end=1098
  _globals['_DELETETOPICREQUEST']._serialized_start=1100
  _globals['_DELETETOPICREQUEST']._serialized_end=1207
  _globals['_DELETETOPICMETADATA']._serialized_start=1209
  _globals['_DELETETOPICMETADATA']._serialized_end=1270
  _globals['_TOPICSERVICE']._serialized_start=1273
  _globals['_TOPICSERVICE']._serialized_end=2191
# @@protoc_insertion_point(module_scope)
