# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/runs/run.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1 import common_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_common__pb2
from yandex.cloud.ai.assistants.v1.threads import message_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/ai/assistants/v1/runs/run.proto\x12\"yandex.cloud.ai.assistants.v1.runs\x1a#yandex/cloud/ai/common/common.proto\x1a*yandex/cloud/ai/assistants/v1/common.proto\x1a\x33yandex/cloud/ai/assistants/v1/threads/message.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa7\x04\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x61ssistant_id\x18\x02 \x01(\t\x12\x11\n\tthread_id\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.ai.assistants.v1.runs.Run.LabelsEntry\x12;\n\x05state\x18\x07 \x01(\x0b\x32,.yandex.cloud.ai.assistants.v1.runs.RunState\x12?\n\x05usage\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.runs.ContentUsage\x12`\n custom_prompt_truncation_options\x18\t \x01(\x0b\x32\x36.yandex.cloud.ai.assistants.v1.PromptTruncationOptions\x12S\n\x19\x63ustom_completion_options\x18\n \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.CompletionOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x02\n\x08RunState\x12\x46\n\x06status\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.ai.assistants.v1.runs.RunState.RunStatus\x12.\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.ai.common.ErrorH\x00\x12K\n\x11\x63ompleted_message\x18\x03 \x01(\x0b\x32..yandex.cloud.ai.assistants.v1.threads.MessageH\x00\"`\n\tRunStatus\x12\x1a\n\x16RUN_STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x42\x0b\n\tStateData\"V\n\x0c\x43ontentUsage\x12\x15\n\rprompt_tokens\x18\x01 \x01(\x03\x12\x19\n\x11\x63ompletion_tokens\x18\x02 \x01(\x03\x12\x14\n\x0ctotal_tokens\x18\x03 \x01(\x03\x42u\n&yandex.cloud.api.ai.assistants.v1.runsZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/runs;runsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.runs.run_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.ai.assistants.v1.runsZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/runs;runs'
  _RUN_LABELSENTRY._options = None
  _RUN_LABELSENTRY._serialized_options = b'8\001'
  _globals['_RUN']._serialized_start=252
  _globals['_RUN']._serialized_end=803
  _globals['_RUN_LABELSENTRY']._serialized_start=758
  _globals['_RUN_LABELSENTRY']._serialized_end=803
  _globals['_RUNSTATE']._serialized_start=806
  _globals['_RUNSTATE']._serialized_end=1124
  _globals['_RUNSTATE_RUNSTATUS']._serialized_start=1015
  _globals['_RUNSTATE_RUNSTATUS']._serialized_end=1111
  _globals['_CONTENTUSAGE']._serialized_start=1126
  _globals['_CONTENTUSAGE']._serialized_end=1212
# @@protoc_insertion_point(module_scope)
