"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SummarizationFieldType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SummarizationFieldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SummarizationFieldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SUMMARIZATION_FIELD_TYPE_UNSPECIFIED: _SummarizationFieldType.ValueType  # 0
    TEXT: _SummarizationFieldType.ValueType  # 1
    TEXT_ARRAY: _SummarizationFieldType.ValueType  # 2

class SummarizationFieldType(_SummarizationFieldType, metaclass=_SummarizationFieldTypeEnumTypeWrapper): ...

SUMMARIZATION_FIELD_TYPE_UNSPECIFIED: SummarizationFieldType.ValueType  # 0
TEXT: SummarizationFieldType.ValueType  # 1
TEXT_ARRAY: SummarizationFieldType.ValueType  # 2
global___SummarizationFieldType = SummarizationFieldType

@typing.final
class Summarization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATEMENTS_FIELD_NUMBER: builtins.int
    @property
    def statements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SummarizationStatement]: ...
    def __init__(
        self,
        *,
        statements: collections.abc.Iterable[global___SummarizationStatement] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["statements", b"statements"]) -> None: ...

global___Summarization = Summarization

@typing.final
class SummarizationStatement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def field(self) -> global___SummarizationField: ...
    @property
    def response(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        field: global___SummarizationField | None = ...,
        response: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field", b"field"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["field", b"field", "response", b"response"]) -> None: ...

global___SummarizationStatement = SummarizationStatement

@typing.final
class SummarizationField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    type: global___SummarizationFieldType.ValueType
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        type: global___SummarizationFieldType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name", "type", b"type"]) -> None: ...

global___SummarizationField = SummarizationField
